PRO ACS_DESC_FILT_DATA, LAT_ARR, LAT_FILL_VAL, SAT_NAME, DATA, DATA_FILL

; ============================================================================
; Purpose: The script determines at which latitude value, in a given latitude 
;    1-D array, a transition in direction is made. For example, if a satellite 
;    ascends towards to North pole and then descend from the North pole, this 
;    script will find the transition.
;    When the transition is found, the data which is before the transition 
;    will be replaced by the value indicated by 'data_fill'.
; 
; Input parameters: 
;    lat_arr      - The 2-D satellite swath latitude values.
;    lat_fill_val - The fill value that is used in the lat_arr variable.
;    sat_name     - The satellite name. This must all in small letters. One of 
;        the following names must be used: terra, aqua, fy3a, fy3b.
;    data_fill    - The value that must be used when data are filtered out. 
; 
; Output:
;    data - The data that must be filtered. Filtered data is replaced by the 
;        indicated by data_fill.
; 
; Author: Liam.Gumley@ssec.wisc.edu, Willem.Marais@ssec.wisc.edu
; ============================================================================

; If the resolution of the latitude array differs from the data array, calculated 
; by what factor does it differ.
lat_dims_arr = size (lat_arr, /DIMENSIONS)
dat_dims_arr = size (data, /DIMENSIONS)
row_factor = dat_dims_arr [1] / lat_dims_arr [1]

; We only need the middle column of the latitude array.
mid_col_lat_arr = reform (lat_arr [lat_dims_arr [0] / 2, *])

; Find the threshold and the starting point of the data.
acs_desc_filt_thr, mid_col_lat_arr, lat_fill_val, sat_name, thr_track_start, dir_start_bl

if thr_track_start NE -1 then begin
    if dir_start_bl EQ 1 then begin
        idx_start = 0
        idx_stop = thr_track_start * row_factor
    endif else begin
        idx_start = thr_track_start * row_factor
        idx_stop = dat_dims_arr [1] - 1
    endelse
    
    data [*, idx_start:idx_stop] = data_fill
endif

END
