PRO ASC_DESC_FILT_BIN_BINFILE, LAT_BIN_FILE, LAT_WIDTH, LAT_LENGTH, LAT_TYPE, SDS_FILLVALUE, BIN_FILE, OUT_FILL_VAL, SAT_NAME, BIN_WIDTH, BIN_LENGTH, BIN_TYPE

; ============================================================================
; Purpose: Morning equator crossing satellites (Terra, FY3A), for example, do 
;     have day light data at the polar region when in ascending mode. Normally 
;     only day light data are in descending mode. The day light data that are 
;     in the ascending mode is of low quality. This script replaces these data 
;     with a given fill value (out_fill_val). The same is done for afternoon 
;     equator crossing satellites (Aqua, FY3B).
; 
; Input parameters:
;     geo_file     - The L1B HDF4 geolocation file of the sensor.
;     bin_file     - The binary data file which will be filtered.
;     out_fill_val - The value that will be used to replace 'low quality' 
;         solar data in the file 'bin_file'
;     sat_name - The name of the satellite of the data. One of the following 
;         names must be used: terra, aqua, fy3a, fy3b.
;     bin_width        - The number of columns in the raster file.
;     bin_length       - The number of rows in the raster file.
;     bin_type         - The data bin_type in the raster file.
; 
; Output parameters:
;     bin_file - This is the same file from which the data are read. The content 
;         in this file is replaced by the filtered data.
; 
; Author: Liam.Gumley@ssec.wisc.edu, Willem.Marais@ssec.wisc.edu
; ============================================================================

; ----------------------------------------------------------------------------
; Get the latitude data from the geolocation file
; ----------------------------------------------------------------------------
openr, lun, lat_bin_file, /GET_LUN
lat_arr = make_array (lat_width, lat_length, TYPE=lat_type)
readu, lun, lat_arr
close, lun

; ----------------------------------------------------------------------------
; Get the data from the file bin_file
; ----------------------------------------------------------------------------
openr, lun, bin_file, /GET_LUN
data_arr = make_array (bin_width, bin_length, TYPE=bin_type)
readu, lun, data_arr
close, lun

; ----------------------------------------------------------------------------
; Filter the data based on the latitude data
; ----------------------------------------------------------------------------
acs_desc_filt_data, lat_arr, sds_fillvalue, sat_name, data_arr, out_fill_val

; ----------------------------------------------------------------------------
; Write the filted data to the file bin_file
; ----------------------------------------------------------------------------
openw, lun, bin_file, /GET_LUN
writeu, lun, data_arr
close, lun

END

