PRO CONDITION_SZENANGLE_BIN, SZEN_BIN_FILE, NR_COLS, NR_ROWS, DTYPE, SCALE_VALUE

; ============================================================================
; Purpose: This script filters out of range sensor zenith angle values in a 
;    sensor zenith angle array. This script assumes that the given sensor 
;    zenith angle data have been scaled by 100.

; 
; Input parameters: 
;    szen_bin_file - The sensor zenith angle data in a binary file.
;    nr_cols       - The number of columns in the data array.
;    nr_rows       - The number of rows in the data array.
;    dtype         - The IDL type of the data array.
; 
; Author: Liam.Gumley@ssec.wisc.edu, Willem.Marais@ssec.wisc.edu
; ============================================================================

szen_data_arr = make_array (nr_cols, nr_rows, TYPE = dtype)

openr, lun, szen_bin_file, /GET_LUN
readu, lun, szen_data_arr
close, lun

idxz_wg = where ((szen_data_arr GT (180 * scale_value)) OR (szen_data_arr LT 0))
idxz_wg_valid_bl = 1
if N_ELEMENTS (idxz_wg) EQ 1 then begin
    if idxz_wg EQ -1 then $
        idxz_wg_valid_bl = 0
endif

if idxz_wg_valid_bl EQ 1 then begin
    szen_data_arr [idxz_wg] = 180 * scale_value
    
    openw, lun, szen_bin_file, /GET_LUN
    writeu, lun, szen_data_arr
    close, lun
endif
END

