PRO FILTER_POLAR_DATA_EDGE, GEO_FILE, BIN_FILE_ARR, BIN_FILE_ARR_LEN, FILL_VALUE, SAT_NAME, WIDTH, LENGTH, TYPE, LAT_THRESHOLD, AMOUNT_SHIFT
; Filter Polar Data Edge
; Some of the polar data has invalid pixels at the edges, when it makes a transition from 
; day to night. This script filters such data out.

; -------------------------------------------------------------------------------------
; Get latitude data
; -------------------------------------------------------------------------------------
hdfid = hdf_sd_start (geo_file)

hdf_sd_varread, hdfid, 'Latitude', lat_arr
; Get the fill value of the latitude array
index_sds = hdf_sd_nametoindex (hdfid, 'Latitude')
sds_varid = hdf_sd_select (hdfid, index_sds)
attindex = hdf_sd_attrfind (sds_varid, '_FillValue')
hdf_sd_attrinfo, sds_varid, attindex, data = sds_fillvalue
if N_ELEMENTS (sds_fillvalue GT 1) then begin
    sds_fillvalue = sds_fillvalue [0]
endif

hdf_sd_endaccess, sds_varid
hdf_sd_end, hdfid

; -------------------------------------------------------------------------------------
; Determine what polar region the data covers
; -------------------------------------------------------------------------------------
north_bl = 1

lat_arr_dim = SIZE (lat_arr, /DIMENSIONS)
lat_nr_cols = lat_arr_dim [0]
lat_nr_rows = lat_arr_dim [1]

mdl_lat_arr = lat_arr [FIX (lat_nr_cols / 2), *]

if mdl_lat_arr [FIX (lat_nr_rows / 2)] GT 0 then begin
    north_bl = 1
endif else begin
    north_bl = 0
endelse

; -------------------------------------------------------------------------------------
; Get the maximum or minimum latitude value. Based on the threshold, continue or not in 
; filtering the data.
; -------------------------------------------------------------------------------------
threshold_bl = 0
max_min_lat_val = MAX (ABS (lat_arr))
if max_min_lat_val GT ABS (lat_threshold) then $
    threshold_bl = 1

; -------------------------------------------------------------------------------------
; The maximum/minimum latitude data exceeds the threshold, therefore continue filtering
; -------------------------------------------------------------------------------------
filter_bl = 0
if threshold_bl EQ 1 then begin
    bin_data = make_array (width, length, TYPE = type)
    openr, lun, bin_file_arr [0], /GET_LUN
    readu, lun, bin_data
    close, lun
    
    ; Create a mask with all the no data equal to zero
    mask = bin_data NE fill_value
    mask_total_clmn = TOTAL (mask, 1)
    
    idx_mask_total = indgen (FIX (length / 10))
    idx_mask_total = temporary (idx_mask_total) * 10

    smpl_vals = mask_total_clmn [idx_mask_total]
    smpl_vals_diff = smpl_vals - shift (smpl_vals, 1)
    smpl_vals_diff = smpl_vals [1:(N_ELEMENTS (smpl_vals) - 1)]
    smpl_vals_diff_len = N_ELEMENTS (smpl_vals_diff)
    
    if north_bl EQ 1 then begin
        if (sat_name EQ 'terra') OR (sat_name EQ 'fy3a') then begin
            if mean (smpl_vals_diff) GT 0 then $
                filter_bl = 1
        endif
        
        if (sat_name EQ 'aqua') OR (sat_name EQ 'fy3b') then begin
            if mean (smpl_vals_diff) LT 0 then $
                filter_bl = 1
        endif
    endif else begin 
        if (sat_name EQ 'terra') OR (sat_name EQ 'fy3a') then begin
            if mean (smpl_vals_diff) LT 0 then $
                filter_bl = 1
        endif
        
        if (sat_name EQ 'aqua') OR (sat_name EQ 'fy3b') then begin
            if mean (smpl_vals_diff) GT 0 then $
                filter_bl = 1
        endif
    endelse
endif

for idx = 0, bin_file_arr_len - 1 do begin
    bin_data = make_array (width, length, TYPE = type)
    openr, lun, bin_file_arr [idx], /GET_LUN
    readu, lun, bin_data
    close, lun
    
    ;mask = bin_data NE fill_value
    
    if filter_bl EQ 1 then begin
        if north_bl EQ 1 then begin
            if (sat_name EQ 'terra') OR (sat_name EQ 'fy3a') then begin
                ;mask [*, amount_shift:(length - 1)] = mask [*, 0:(length - 1 - amount_shift)]
                ;mask [*, 0] = 0
                row_idx_start = 0
                row_idx_stop = amount_shift - 1
            endif
            
            if (sat_name EQ 'aqua') OR (sat_name EQ 'fy3b') then begin
                ;mask [*, 0:(length - 1 - amount_shift)] = mask [*, amount_shift:(length - 1)]
                ;mask [*, length - 1] = 0
                row_idx_start = length - 1 - amount_shift
                row_idx_stop = length - 1
            endif
        endif else begin 
            if (sat_name EQ 'terra') OR (sat_name EQ 'fy3a') then begin
                ;mask [*, 0:(length - 1 - amount_shift)] = mask [*, amount_shift:(length - 1)]
                ;mask [*, length - 1] = 0
                row_idx_start = 0
                row_idx_stop = amount_shift - 1
            endif
            
            if (sat_name EQ 'aqua') OR (sat_name EQ 'fy3b') then begin
                ;mask [*, amount_shift:(length - 1)] = mask [*, 0:(length - 1 - amount_shift)]
                ;mask [*, 0] = 0
                row_idx_start = length - 1 - amount_shift
                row_idx_stop = length - 1
            endif
        endelse
    endif
    
    if filter_bl EQ 1 then begin
        ;idx_eq_fill = where (mask EQ 0)
        ;bin_data [idx_eq_fill] = fill_value
        
        bin_data [*, row_idx_start:row_idx_stop] = fill_value
        
        openw, lun, bin_file_arr [idx], /GET_LUN
        writeu, lun, bin_data
        close, lun
    endif
endfor

END
