PRO HDF5_VIIRS_GEODATA_TO_BIN, HDF5_FILE_STR, DATASET_PATH_STR, LAT_PREFIX_STR, LON_PREFIX_STR, SENZ_PREFIX_STR

;- Open the file
file_id = h5f_open (hdf5_file_str)

; ===========================================================================
;- Read the latitude data
; ===========================================================================
dataset_name = 'Latitude'
data_id = h5d_open (file_id, dataset_path_str + '/' + dataset_name)
lat_arr = h5d_read (data_id)
h5d_close, data_id

; Filter fill values
idx = where (lat_arr LT -900.0)
lat_arr [idx] = -999.0

; Write data to binary file
; Get the dimensions of the SDS array
dimm_arr = size (lat_arr, /dimensions)
; Get the data type
data_type_int = size (lat_arr, /type)
; Construct the output file name
out_file_name_str = lat_prefix_str + "_" + $
                    strtrim (string (dimm_arr [0]), 1) + "_" + $
                    strtrim (string (dimm_arr [1]), 1) + "_" + $
                    strtrim (string (data_type_int), 1) + ".dat"

; Write data to output binary file
openw, lun, out_file_name_str, /get_lun
writeu, lun, temporary (lat_arr)
free_lun, lun

; ===========================================================================
;- Read the longitude data
; ===========================================================================
dataset_name = 'Longitude'
data_id = h5d_open (file_id, dataset_path_str + '/' + dataset_name)
lon_arr = h5d_read (data_id)
h5d_close, data_id

; Filter fill values
idx = where (lon_arr LT -900.0)
lon_arr [idx] = -999.0

; Write data to binary file
; Get the dimensions of the SDS array
dimm_arr = size (lon_arr, /dimensions)
; Get the data type
data_type_int = size (lon_arr, /type)
; Construct the output file name
out_file_name_str = lon_prefix_str + "_" + $
                    strtrim (string (dimm_arr [0]), 1) + "_" + $
                    strtrim (string (dimm_arr [1]), 1) + "_" + $
                    strtrim (string (data_type_int), 1) + ".dat"

; Write data to output binary file
openw, lun, out_file_name_str, /get_lun
writeu, lun, temporary (lon_arr)
free_lun, lun

; ===========================================================================
;- Read the satellite zenith angle data
; ===========================================================================
dataset_name = 'SatelliteZenithAngle'
data_id = h5d_open (file_id, dataset_path_str + '/' + dataset_name)
senz_arr = h5d_read (data_id)
h5d_close, data_id

; Filter fill values
idx = where (senz_arr LT -900.0)
senz_arr [idx] = -999.0

; The rest of MIPS expects the sensor zenith data to be in an integer format. 
; Convert it to such, and scale it with 100.
senz_arr_int_scaled = FIX (abs (temporary (senz_arr)) * 100.0)
senz_arr_int_scaled [idx] = 180 * 100

; Write data to binary file
; Get the dimensions of the SDS array
dimm_arr = size (senz_arr_int_scaled, /dimensions)
; Get the data type
data_type_int = size (senz_arr_int_scaled, /type)
; Construct the output file name
out_file_name_str = senz_prefix_str + "_" + $
                    strtrim (string (dimm_arr [0]), 1) + "_" + $
                    strtrim (string (dimm_arr [1]), 1) + "_" + $
                    strtrim (string (data_type_int), 1) + ".dat"

; Write data to output binary file
openw, lun, out_file_name_str, /get_lun
writeu, lun, temporary (senz_arr_int_scaled)
free_lun, lun

;- Close the file
h5f_close, file_id

END

