PRO LATLON_TO_POLAR_TILES, lon_arr, lat_arr, tile_lw, nr_rows, nr_cols, nrth_sth_flg, tilenr_arr
; Latitude Longitude to Polar Tile Numbers
;
; Notes:
;   1. nr_rows and nr_cols must both be even numbers
;
; lon_arr      - Longitude array (degrees)
; lat_arr      - Latitude array (degrees)
; tile_lw      - Tile width and length (meters)
; nr_rows      - The number of rows in the tile grid
; nr_cols      - The number of columns in the tile grid
; nrth_sth_flg - North South Flag. Equal to 0 if South, 1 if North.
; tilenr_arr   - The polar tile number array

if nr_rows mod 2 NE 0 then begin
    print, "The number of rows of the tile grid must be an even number"
    return
endif

if nr_cols mod 2 NE 0 then begin
    print, "The number of columns of the tile grid must be an even number"
    return
endif

;print, 'max (lon_arr): ', max (lon_arr)
;print, 'min (lon_arr): ', min (lon_arr)
;print, 'max (lat_arr): ', max (lat_arr)
;print, 'min (lat_arr): ', min (lat_arr)

case nrth_sth_flg of
    0: begin
        ; Project coordinates for Southern pole
        stereo_graphic_proj, lon_arr, lat_arr, -90.0, 0.0, 6371007.181, x_arr, y_arr
    end

    1: begin
        ; Project coordinates for Northen pole
        stereo_graphic_proj, lon_arr, lat_arr, 90.0, 0.0, 6371007.181, x_arr, y_arr
    end
endcase

tile_lw = double (tile_lw)
nr_cols = double (nr_cols)
nr_rows = double (nr_rows)

; Calculate the lower left coordinate of the tile grid
ll_tg_x = tile_lw * (nr_cols / 2.0) * (-1.0)
ll_tg_y = tile_lw * (nr_rows / 2.0) * (-1.0)

;print, 'max (x_arr): ', max (x_arr)
;print, 'min (x_arr): ', min (x_arr)
;print, 'max (y_arr): ', max (y_arr)
;print, 'min (y_arr): ', min (y_arr)

; Offset the projected coordinates with the lower left coordinates of the 
; overall grid
x_arr = x_arr - ll_tg_x
y_arr = y_arr - ll_tg_y

;print, 'max (x_arr): ', max (x_arr)
;print, 'min (x_arr): ', min (x_arr)
;print, 'max (y_arr): ', max (y_arr)
;print, 'min (y_arr): ', min (y_arr)

; Calculate the row and column numbers of the projected coordinates
; It could be that some of the numbers are so large, it cannot be presented 
; with a 32-bit word. Ignore any math errors
old_EXCEPT=!EXCEPT
!EXCEPT=0

x_tile_arr = floor (x_arr / tile_lw)
y_tile_arr = floor (y_arr / tile_lw)

; Clear devide by zero error
null_val = check_math (MASK = 16)
; Clear illegal operand error
null_val = check_math (MASK = 128)
!EXCEPT=old_EXCEPT

;print, 'max (x_tile_arr): ', max (x_tile_arr)
;print, 'min (x_tile_arr): ', min (x_tile_arr)
;print, 'max (y_tile_arr): ', max (y_tile_arr)
;print, 'min (y_tile_arr): ', min (y_tile_arr)

; Filter the row and column numbers which are outside the specified 
; row and column specification
x_filt_msk = (x_tile_arr GE 0) AND (x_tile_arr LT nr_cols)
y_filt_msk = (y_tile_arr GE 0) AND (y_tile_arr LT nr_rows)
filt_msk = x_filt_msk AND y_filt_msk

if TOTAL (filt_msk) EQ 0 then begin
    ; If the filter mask equals zero, return an array with one element which 
    ; is equal to -1
    tilenr_arr = [-1]
endif else begin
    ; Generate the tile numbers
    filt_idx = where (filt_msk EQ 1)
    
    x_roi_arr = x_tile_arr [filt_idx]
    y_roi_arr = y_tile_arr [filt_idx]

    tilenr_arr = x_roi_arr + (y_roi_arr * nr_cols)
endelse

END

