pro make_user_kml,sensor_name,sat_array,web_path,filename,sitename,sitelat,sitelon
;---------------------------------------------------------------------
; This program will create the .kml file that a user can d/l to their
; local machine that will point to current.terra/aqua.kml, which
; resides on the SSEC GE server.  This only needs to be run if the
; web path or file names of the GE data changes, or if newer meta data
; is added for the users.
;
; INPUT:
;  web_path: The www address where current.terra.kml and
;  current.aqua.kml reside, must end with a '/'.
;
; OUTPUT:
;  A kml file that a user can d/l onto their machine so that they can
;  enjoy the SSEC MODIS GE products!
;
; KEYWORD:
;  filename - set to a modis swath jpeg name for a given day to write
;  out a downloadable file that points to the Terra or Aqua GE data
;  for that particluar day.
;
; HARDWIRED: The output it saved to ../kml/
;
; AUTHOR: Amato Evan - CIMSS/UW-Madison amatoe@ssec.wisc.edu
;---------------------------------------------------------------------

; Get satellite name and date

sat_name = strmid(filename,8,4) ;terr or aqua
if(sat_name eq 'terr')then sat_name = 'terra'
if(sat_name eq 'npp.')then sat_name = 'npp'

;date = strmid(filename,strpos(filename,'.jpg')-22,8)
;band_comb = strmid(filename,strpos(filename,'.jpg')-13,11)
sat_name_str_len = strlen (sat_name)
sat_name_str_pos = strpos (filename, sat_name)
date = strmid (filename, sat_name_str_pos + sat_name_str_len + 1, 8)
band_comb = strmid (filename, sat_name_str_pos + sat_name_str_len + 1 + 8 + 1, 14)

; Make the KML file for the current date

openw,u,sitename+'_'+sensor_name+'_'+band_comb+'_Today.kml',/get_lun

;write the opening lines
printf,u,'<?xml version="1.0" encoding="UTF-8"?>'
printf,u,'<kml xmlns="http://earth.google.com/kml/2.2">'
printf,u,'<Document>'

lon_string=string(float(sitelon), format='(f8.3)')
lat_string=string(float(sitelat), format='(f8.3)')

printf,u,'	<name>'+sitename+' '+sensor_name+' Today; Current day</name>'
printf,u,'	<LookAt>'
printf,u,' 		<longitude>'+lon_string+'</longitude>'
printf,u,'		<latitude>'+lat_string+'</latitude>'
printf,u,' 		<altitudeMode>absolute</altitudeMode>'
printf,u,' 		<altitude>10000000</altitude>'
printf,u,' 		<range>0.1</range>'
printf,u,' 		<tilt>0</tilt>'
printf,u,' 		<heading>0</heading>'
printf,u,'	</LookAt>'
printf,u,'	<styleUrl>#check</styleUrl>'
printf,u,'	<Style id="hideChildren">'
printf,u,'		<ListStyle> '
printf,u,' 			<listItemType>checkHideChildren</listItemType>'
printf,u,' 		</ListStyle>'
printf,u,' 	</Style>'
printf,u,'	<Style id="radioFolder">'
printf,u,' 		<ListStyle>'
printf,u,' 			<listItemType>radioFolder</listItemType>'
printf,u,'		</ListStyle>'
printf,u,'	</Style>'
printf,u,'	<NetworkLink>'
printf,u,'		<name>' + STRUPCASE (sat_array [0]) + '</name>'
printf,u,'		<visibility>0</visibility>'
printf,u,'		<styleUrl>#hideChildren</styleUrl>'
printf,u,'		<Link>'
printf,u,'	           <href>'+web_path+sitename+'.current.' + sat_array [0] + '.'+ band_comb + '.kml</href>'
printf,u,'                   <refreshMode>onInterval</refreshMode>'
printf,u,'                   <refreshInterval>600</refreshInterval>'
printf,u,'		</Link>'
printf,u,'	</NetworkLink>'
for index = 1, N_ELEMENTS (sat_array) - 1 do begin
    printf,u,'	<NetworkLink>'
    printf,u,'		<name>' + STRUPCASE (sat_array [index]) + '</name>'
    printf,u,'		<styleUrl>#hideChildren</styleUrl>'
    printf,u,'		<Link>'
    printf,u,'	           <href>'+web_path+sitename+'.current.' + sat_array [index] + '.' + band_comb + '.kml</href>'
    printf,u,'                   <refreshMode>onInterval</refreshMode>'
    printf,u,'                   <refreshInterval>600</refreshInterval>'
    printf,u,'		</Link>'
    printf,u,'	</NetworkLink>'
endfor
printf,u,'</Document>'
printf,u,'</kml>'

close,u
free_lun,u

;---------------------------------------------------------------------

; Make the KML file for the given day

out_file=sitename+'.'+date+'.'+sat_name+'.'+band_comb+'.kml'
openw,u,out_file,/get_lun

printf,u,'<?xml version="1.0" encoding="UTF-8"?>'
printf,u,'<kml xmlns="http://earth.google.com/kml/2.2">'
printf,u,'<Document>'

printf,u,'    <NetworkLink>'
printf,u,'	<name>'+sitename+' '+sensor_name+' Today; Day '+date+'</name>'
printf,u,'	<LookAt>'
printf,u,' 		<longitude>'+lon_string+'</longitude>'
printf,u,'		<latitude>'+lat_string+'</latitude>'
printf,u,' 		<altitudeMode>absolute</altitudeMode>'
printf,u,' 		<altitude>10000000</altitude>'
printf,u,' 		<range>0.1</range>'
printf,u,' 		<tilt>0</tilt>'
printf,u,' 		<heading>0</heading>'
printf,u,'	</LookAt>'
printf,u,'       <Style>'
printf,u,'           <ListStyle>'
printf,u,'               <listItemType>checkHideChildren</listItemType>'
printf,u,'           </ListStyle>'
printf,u,'       </Style>'
printf,u,'       <Link>'
printf,u,'           <href>'+web_path+date+'/'+band_comb+'/'+date+'.'+band_comb+'.'+sat_name+'.kml</href>'
printf,u,'           <refreshMode>onInterval</refreshMode>'
printf,u,'           <refreshInterval>600</refreshInterval>'
printf,u,'       </Link>'
printf,u,'    </NetworkLink>'

;write logo image information if file exists
file_name='logo.jpg'
result=file_search(file_name)
if (result[0] ne '') then begin
  printf,u,'    <ScreenOverlay id="Logo">'
  printf,u,'       <name>Logo</name>'
  printf,u,'       <visibility>1</visibility>'
  printf,u,'        <open>1</open>'
  printf,u,'        <color>ffffffff</color>'
  printf,u,'        <drawOrder>0</drawOrder>'
  printf,u,'        <Icon>'
  printf,u,'          <href>'+web_path+file_name+'</href>'
  printf,u,'        </Icon>'
  printf,u,'        <overlayXY x="0" y="1" xunits="fraction" yunits="fraction"/>'
  printf,u,'        <screenXY x="0" y="1" xunits="fraction" yunits="fraction"/>'
  printf,u,'        <size x="0" y="0" xunits="fraction" yunits="fraction"/>'
  printf,u,'      </ScreenOverlay>'
endif

;write update image information if file exists
file_name=sat_name+'.'+date+'.update.jpg'
result=file_search(file_name)
if result[0] ne '' then begin
  printf,u,'    <ScreenOverlay id="Update">'
  printf,u,'       <name>Update</name>'
  printf,u,'       <visibility>1</visibility>'
  printf,u,'        <open>1</open>'
  printf,u,'        <color>ffffffff</color>'
  printf,u,'        <drawOrder>0</drawOrder>'
  printf,u,'        <Icon>'
  printf,u,'          <href>'+web_path+file_name+'</href>'
  printf,u,'        </Icon>'
  printf,u,'        <overlayXY x="0.5" y="1" xunits="fraction" yunits="fraction"/>'
  printf,u,'        <screenXY x="0.5" y="1" xunits="fraction" yunits="fraction"/>'
  printf,u,'        <size x="0" y="0" xunits="fraction" yunits="fraction"/>'
  printf,u,'      </ScreenOverlay>'
endif

printf,u,'</Document>'
printf,u,'</kml>'

close,u
free_lun,u

; Copy to current KML file (for this day only)
spawn, 'date +%Y%m%d; date +%Y%m%d -d yesterday', result
if (date eq result[0] or date eq result[1]) then begin
  spawn, 'cp '+out_file+' '+sitename+'.current.'+sat_name+'.' + band_comb +'.kml'
endif

end
;-------------------------------------------------------------
