PRO POLAR_TILES_TO_LATLON, TILENR_ARR, TILE_LW, NR_ROWS, NR_COLS, NRTH_STH_FLG, LONG_DEG_ARR, LAT_DEG_ARR

; Stereo Graphic Projection. Forumulation take from the following source:
;     Map Projections - A Working Manual, John P Snyder 
;
; Arguments:
; 
; [input]
; tilenr_arr   - The tile number which are going to be converted into corner coordindates
; tile_lw      - The length and width of the tile in meters
; nr_rows      - The number of rows in the tile grid
; nr_cols      - The number of columns in the tile grid
; nrth_sth_flg - North South Flag. Equal to 0 if South, 1 if North.
; 
; [output]
; long_deg_arr - The longitude array values. There are four columns in each row entry. Going in 
;                an clock-wise direction, first the UL corner is given.
; lat_deg_arr  - The latitude array values. There are four columns in each row entry. Going in 
;                an clock-wise direction, first the UL corner is given.

; Create the array which will hold the projection data

;tilenr_arr_len = N_ELEMENTS (tilenr_arr)
;ll_x_arr = dblarr (4, tilenr_arr_len) ; Lower left coordinates
;ll_y_arr = dblarr (4, tilenr_arr_len)
;
;ul_x_arr = dblarr (4, tilenr_arr_len) ; Upper left coordinates
;ul_y_arr = dblarr (4, tilenr_arr_len)
;
;ur_x_arr = dblarr (4, tilenr_arr_len) ; Upper right coordinates
;ur_y_arr = dblarr (4, tilenr_arr_len)
;
;lr_x_arr = dblarr (4, tilenr_arr_len) ; Lower right coordinates
;lr_y_arr = dblarr (4, tilenr_arr_len)
;
;; Calculate the corner map coordinates of each tile
;tile_grid_ll_x = tile_lw * (nr_cols / 2.0)
;tile_grid_ll_y = tile_lw * (nr_rows / 2.0)
;
;row_nr_arr = floor (tilenr_arr / nr_cols)
;col_nr_arr = tilenr_arr - (row_nr_arr * nr_cols)
;
;ll_x_arr = (col_nr_arr * tile_lw) - tile_grid_ll_x ; Lower left
;ll_y_arr = (row_nr_arr * tile_lw) - tile_grid_ll_y
;
;ul_x_arr = ll_x_arr ; Upper left
;ul_y_arr = ll_y_arr + tile_lw
;
;ur_x_arr = ll_x_arr + tile_lw ; Upper right
;ur_y_arr = ul_y_arr
;
;lr_x_arr = ur_x_arr ; Lower right
;lr_y_arr = ll_y_arr

polar_tiles_to_mapxy, tilenr_arr, nr_rows, nr_cols, tile_lw, x_arr, y_arr

; Inverse project
if nrth_sth_flg EQ 0 then begin
    ctr_deg_lat = -90
endif else begin
    ctr_deg_lat = 90
endelse

; Inverse project the corner coordinates
stereo_graphic_invproj, x_arr [3, *], y_arr [3, *], ctr_deg_lat, 0.0, 6371007.181, ll_long_deg_arr, ll_lat_deg_arr
stereo_graphic_invproj, x_arr [0, *], y_arr [0, *], ctr_deg_lat, 0.0, 6371007.181, ul_long_deg_arr, ul_lat_deg_arr
stereo_graphic_invproj, x_arr [1, *], y_arr [1, *], ctr_deg_lat, 0.0, 6371007.181, ur_long_deg_arr, ur_lat_deg_arr
stereo_graphic_invproj, x_arr [2, *], y_arr [2, *], ctr_deg_lat, 0.0, 6371007.181, lr_long_deg_arr, lr_lat_deg_arr

; Write data to the output array
tilenr_arr_len = N_ELEMENTS (tilenr_arr)
lat_deg_arr = dblarr (4, tilenr_arr_len)
long_deg_arr = dblarr (4, tilenr_arr_len)

lat_deg_arr [0, *] = ul_lat_deg_arr
lat_deg_arr [1, *] = ur_lat_deg_arr
lat_deg_arr [2, *] = lr_lat_deg_arr
lat_deg_arr [3, *] = ll_lat_deg_arr

long_deg_arr [0, *] = ul_long_deg_arr
long_deg_arr [1, *] = ur_long_deg_arr
long_deg_arr [2, *] = lr_long_deg_arr
long_deg_arr [3, *] = ll_long_deg_arr

END
