; The code was adapted from Liam.Gumley@ssec.wisc.edu's modis_reproject.pro code

FUNCTION CREFL_UNSCALE, DATA
;- Convert corrected reflectance scaled integer data to float and set invalid pixels to -1.0
loc = where(data eq 32767, count)
data = data * 0.0001
if (count gt 0) then data[loc] = -1.0
return, data
END

PRO REPROJECT_BINARY, HRES_PROJ_BIN, LRES_HRES_PROJ_BIN, LRES_PROJ_BIN_ARR, OUT_PNG, $
                      NR_COLUMNS, NR_ROWS, ARR_TYPE, SHARPEN=SHARPEN, $
                      ENHC_FILE=ENHC_FILE

;+
; Create MODIS 250 meter RGB PNG output given reprojected
; input binary files
;
; Usage
; MODIS_REPROJECT_BINARY, HRES_PROJ_BIN, LRES_HRES_PROJ_BIN, LRES_PROJ_BIN_ARR, OUT_PNG, 
;                         NR_COLUMNS, NR_ROWS, ARR_TYPE, SHARPEN=SHARPEN
;
; Input
; HRES_PROJ_BIN     is the reprojected corrected reflectance (binary) from a HRES band
; LRES_HRES_PROJ_BIN is the reprojected corrected reflectance (binary) from a HRES band which is the 
;                  counter part of the HRES band
; LRES_PROJ_BIN_ARR is the reprojected corrected reflectance (binary) HRES bands for red, blue, green
; NR_COLUMNS       is the number of columns in the binary files
; NR_ROWS          is the number of rows in the binary files
; ARR_TYPE         is the IDL data type in the binary files
;
; Output
; OUT_PNG is the output PNG file name
;-

;- Check arguments
if (n_elements(sharpen) eq 0) then sharpen = 1

;- Read reprojected HRES sharpening band
openr, lun, hres_proj_bin, /get_lun
sharp_hres = make_array (nr_columns, nr_rows, type=arr_type)
readu, lun, sharp_hres
free_lun, lun

;- Read reprojected HRES sharpening band
openr, lun, lres_hres_proj_bin, /get_lun
sharp_lres = make_array (nr_columns, nr_rows, type=arr_type)
readu, lun, sharp_lres
free_lun, lun

;- Unscale the HRES and LRES sharpening bands
sharp_hres = crefl_unscale(temporary(sharp_hres))
sharp_lres = crefl_unscale(temporary(sharp_lres))

;- Compute sharpening ratio
ratio = temporary(sharp_lres) / temporary(sharp_hres)
;- The sharp_hres variable could have zero values. Clear 
;- devide by zero errors and illegal operand errors
null_val = check_math (MASK = 16)
null_val = check_math (MASK = 128)

;- Read reprojected HRES red, green, and blue bands from HDF
openr, lun, lres_proj_bin_arr [0], /get_lun
red = make_array (nr_columns, nr_rows, type=arr_type)
readu, lun, red
free_lun, lun

openr, lun, lres_proj_bin_arr [1], /get_lun
grn = make_array (nr_columns, nr_rows, type=arr_type)
readu, lun, grn
free_lun, lun

openr, lun, lres_proj_bin_arr [2], /get_lun
blu = make_array (nr_columns, nr_rows, type=arr_type)
readu, lun, blu
free_lun, lun

;- Convert to reflectance
red = crefl_unscale(temporary(red))
grn = crefl_unscale(temporary(grn))
blu = crefl_unscale(temporary(blu))

;- Create sharpened red, green, blue bands
loc = where(ratio gt 0.0, count)
if (count gt 0) then begin
  red[loc] = red[loc] / ratio[loc]
  grn[loc] = grn[loc] / ratio[loc]
  blu[loc] = blu[loc] / ratio[loc]
endif

;- Create RGB image
;true = modis_false_color(temporary(red), temporary(grn), temporary(blu), /cloud)
if keyword_set (enhc_file) then begin
    true = modis_false_color(red, grn, blu, ENHC_FILE=enhc_file)
endif else begin
    true = modis_false_color(red, grn, blu, /cloud)
endelse

; Added by Willem.Marais@ssec.wisc.edu - 25 October 2010
;- Clamp scaled zero values
true [0, *, *] = true [0, *, *] * (red GT 0)
true [1, *, *] = true [1, *, *] * (grn GT 0)
true [2, *, *] = true [2, *, *] * (blu GT 0)

;;- Write TIFF true color image
;write_tiff, out_tiff, true, compression=1
;print, out_tiff, format='("(Created TIFF image ", a, ")")'
; - Write PNG true color image

; IDL's image refrence frame is bottom left AND NOT top left
true = reverse (temporary (true), 3)
write_png, out_png, true 
print, out_png, format='("(Created PNG image ", a, ")")'

END

