; The code was adapted from Liam.Gumley@ssec.wisc.edu's modis_reproject.pro code

FUNCTION CREFL_UNSCALE, DATA
;- Convert corrected reflectance scaled integer data to float and set invalid pixels to -1.0
loc = where(data eq 32767, count)
data = data * 0.0001
if (count gt 0) then data[loc] = -1.0
return, data
END

PRO REPROJECT_BINARY_QKM, QKM_PROJ_BIN_ARR, OUT_PNG, $
                          NR_COLUMNS, NR_ROWS, ARR_TYPE, SHARPEN=SHARPEN, $
                          ENHC_FILE=ENHC_FILE

;+
; Create MODIS 250 meter RGB PNG output given reprojected
; input binary files
;
; Usage
; MODIS_REPROJECT_BINARY, QKM_PROJ_BIN_ARR, OUT_PNG, 
;                         NR_COLUMNS, NR_ROWS, ARR_TYPE, SHARPEN=SHARPEN
;
; Input
; QKM_PROJ_BIN_ARR is the reprojected corrected reflectance (binary) QKM bands for red, blue, green
; NR_COLUMNS       is the number of columns in the binary files
; NR_ROWS          is the number of rows in the binary files
; ARR_TYPE         is the IDL data type in the binary files
;
; Output
; OUT_PNG is the output PNG file name
;-

;- Check arguments
if (n_elements(sharpen) eq 0) then sharpen = 1

;- Read reprojected QKM red, green, and blue bands from HDF
openr, lun, qkm_proj_bin_arr [0], /get_lun
red = make_array (nr_columns, nr_rows, type=arr_type)
readu, lun, red
free_lun, lun

openr, lun, qkm_proj_bin_arr [1], /get_lun
grn = make_array (nr_columns, nr_rows, type=arr_type)
readu, lun, grn
free_lun, lun

openr, lun, qkm_proj_bin_arr [2], /get_lun
blu = make_array (nr_columns, nr_rows, type=arr_type)
readu, lun, blu
free_lun, lun

;- Convert to reflectance
red = crefl_unscale(temporary(red))
grn = crefl_unscale(temporary(grn))
blu = crefl_unscale(temporary(blu))

;- Create RGB image
;true = modis_false_color(temporary(red), temporary(grn), temporary(blu), /cloud)
if keyword_set (enhc_file) then begin
    true = modis_false_color(red, grn, blu, ENHC_FILE=enhc_file)
endif else begin
    true = modis_false_color(red, grn, blu, /cloud)
endelse

; Added by Willem.Marais@ssec.wisc.edu - 25 October 2010
;- Clamp scaled zero values
true [0, *, *] = true [0, *, *] * (red GT 0)
true [1, *, *] = true [1, *, *] * (grn GT 0)
true [2, *, *] = true [2, *, *] * (blu GT 0)

;;- Write TIFF true color image
;write_tiff, out_tiff, true, compression=1
;print, out_tiff, format='("(Created TIFF image ", a, ")")'
; - Write PNG true color image

; IDL's image refrence frame is bottom left AND NOT top left
true = reverse (temporary (true), 3)
write_png, out_png, true 
print, out_png, format='("(Created PNG image ", a, ")")'

END

