PRO STEREO_GRAPHIC_INVPROJ, x_arr, y_arr, ctr_deg_lat, ctr_deg_lon, radius, long_deg_arr, lat_deg_arr 

; Stereo Graphic Projection. Forumulation take from the following source:
;     Map Projections - A Working Manual, John P Snyder 
;
; Arguments:
; 
; [input]
; x_arr    - The x coordinate value to be unprojected
; y_arr    - The y coordinate value to be unprojected
; ctr_lat  - The center latitude value which is a parameter for the projection
; ctr_lon  - The center longitude value which is a parameter for the projection
; radius   - The radius of the earth, which is preceived to be a sphere in the projection
; 
; [output]
; long_arr - The longitude array values
; lat_arr  - The latitude array values

ctr_lat_rad = ctr_deg_lat * (!PI / 180.0)
ctr_lon_rad = ctr_deg_lon * (!PI / 180.0)

k_0 = 1
p = (x_arr^2 + y_arr^2)^0.5
c = 2 * atan (p / (2 * radius * k_0))

old_EXCEPT=!EXCEPT
!EXCEPT=0
lat_arr = asin (cos (c) * sin (ctr_lat_rad) + y_arr * sin (c) * cos (ctr_lat_rad) / p)
if ctr_deg_lat LT 0 then begin
    long_arr = ctr_lon_rad + atan (x_arr / y_arr)
endif else begin
    long_arr = ctr_lon_rad + atan (x_arr / (y_arr * (-1.0)))
endelse
; Clear devide by zero error
null_val = check_math (MASK = 16)
; Clear illegal operand error
null_val = check_math (MASK = 128)
!EXCEPT=old_EXCEPT

long_deg_arr = long_arr * (180.0 / !PI)
lat_deg_arr  = lat_arr  * (180.0 / !PI)

if TOTAL ((y_arr EQ 0) AND (x_arr EQ 0)) GT 0 then begin
    i_wz = where ((y_arr EQ 0) AND (x_arr EQ 0))
    long_deg_arr [i_wz] = ctr_deg_lon
    lat_deg_arr [i_wz]  = ctr_deg_lat
endif

if ctr_deg_lat LT 0 then begin
    ; For the South pole coodinates, the postive y axis is aligned to North (0 degree), 
    ; and postive x axis is aligned to East (90 degree). Between East and South, the 
    ; longitude coordinates must be adjusted by adding 180 degrees. Between South and 
    ; West, the longitude coordinates must be adjusted by subtracting 180 degrees.
    
    tmp_mask = (x_arr GE 0) AND (y_arr LT 0)
    if TOTAL (tmp_mask) GT 0 then begin
        tmp_idx = where (tmp_mask)
        long_deg_arr [tmp_idx] = long_deg_arr [tmp_idx] + 180.0
    endif

    tmp_mask = (x_arr LT 0) AND (y_arr LT 0)
    if TOTAL (tmp_mask) GT 0 then begin
        tmp_idx = where (tmp_mask)
        long_deg_arr [tmp_idx] = long_deg_arr [tmp_idx] - 180.0
    endif
endif else begin
    ; For the  North pole coodinates, the postive y axis is aligned to South (+-180 degree), 
    ; and postive x axis is aligned to East (90 degree). Between East and South, the 
    ; longitude coordinates must be adjusted by adding 180 degrees. Between South and 
    ; West, the longitude coordinates must be adjusted by subtracting 180 degrees.
    
    tmp_mask = (x_arr GE 0) AND (y_arr GE 0)
    if TOTAL (tmp_mask) GT 0 then begin
        tmp_idx = where (tmp_mask)
        long_deg_arr [tmp_idx] = long_deg_arr [tmp_idx] + 180.0
    endif

    tmp_mask = (x_arr LT 0) AND (y_arr GE 0)
    if TOTAL (tmp_mask) GT 0 then begin
        tmp_idx = where (tmp_mask)
        long_deg_arr [tmp_idx] = long_deg_arr [tmp_idx] - 180.0
    endif
endelse

END
