PRO VIIRS_GEODATA_FILTER, LAT_FILEP_STR, LON_FILEP_STR, SENZ_FILEP_STR, DIM0_INT, DIM1_INT

;- Open the file
;file_id = h5f_open (hdf5_file_str)

; ===========================================================================
;- Read the latitude data
; ===========================================================================
; dataset_name = 'Latitude'
; data_id = h5d_open (file_id, dataset_path_str + '/' + dataset_name)
; lat_arr = h5d_read (data_id)
; h5d_close, data_id
; 
; ; Filter fill values
; idx = where (lat_arr LT -900.0)
; lat_arr [idx] = -999.0
; 
; ; Write data to binary file
; ; Get the dimensions of the SDS array
; dimm_arr = size (lat_arr, /dimensions)
; ; Get the data type
; data_type_int = size (lat_arr, /type)
; ; Construct the output file name
; out_file_name_str = lat_prefix_str + "_" + $
;                     strtrim (string (dimm_arr [0]), 1) + "_" + $
;                     strtrim (string (dimm_arr [1]), 1) + "_" + $
;                     strtrim (string (data_type_int), 1) + ".dat"

lat_arr = make_array (dim0_int, dim1_int, TYPE=4)
; Read data from latitude binary file
openr, lun, lat_filep_str, /get_lun
readu, lun, lat_arr
free_lun, lun

; Filter fill values
idx = where (lat_arr LT -900.0)
if n_elements (idx) GT 1 then begin
    lat_arr [idx] = -999.0
end

; Write data to output binary file
openw, lun, lat_filep_str, /get_lun
writeu, lun, temporary (lat_arr)
free_lun, lun

; ===========================================================================
;- Read the longitude data
; ===========================================================================
; dataset_name = 'Longitude'
; data_id = h5d_open (file_id, dataset_path_str + '/' + dataset_name)
; lon_arr = h5d_read (data_id)
; h5d_close, data_id
; 
; ; Filter fill values
; idx = where (lon_arr LT -900.0)
; lon_arr [idx] = -999.0
; 
; ; Write data to binary file
; ; Get the dimensions of the SDS array
; dimm_arr = size (lon_arr, /dimensions)
; ; Get the data type
; data_type_int = size (lon_arr, /type)
; ; Construct the output file name
; out_file_name_str = lon_prefix_str + "_" + $
;                     strtrim (string (dimm_arr [0]), 1) + "_" + $
;                     strtrim (string (dimm_arr [1]), 1) + "_" + $
;                     strtrim (string (data_type_int), 1) + ".dat"
; 
; ; Write data to output binary file
; openw, lun, out_file_name_str, /get_lun
; writeu, lun, temporary (lon_arr)
; free_lun, lun

lon_arr = make_array (dim0_int, dim1_int, TYPE=4)
; Read data from longitude binary file
openr, lun, lon_filep_str, /get_lun
readu, lun, lon_arr
free_lun, lun

; Filter fill values
idx = where (lon_arr LT -900.0)
if n_elements (idx) GT 1 then begin
    lon_arr [idx] = -999.0
end

; Write data to output binary file
openw, lun, lon_filep_str, /get_lun
writeu, lun, temporary (lon_arr)
free_lun, lun

; ===========================================================================
;- Read the satellite zenith angle data
; ===========================================================================
; dataset_name = 'SatelliteZenithAngle'
; data_id = h5d_open (file_id, dataset_path_str + '/' + dataset_name)
; senz_arr = h5d_read (data_id)
; h5d_close, data_id
; 
; ; Filter fill values
; idx = where (senz_arr LT -900.0)
; senz_arr [idx] = -999.0
; 
; ; The rest of MIPS expects the sensor zenith data to be in an integer format. 
; ; Convert it to such, and scale it with 100.
; senz_arr_int_scaled = FIX (abs (temporary (senz_arr)) * 100.0)
; senz_arr_int_scaled [idx] = 180 * 100
; 
; ; Write data to binary file
; ; Get the dimensions of the SDS array
; dimm_arr = size (senz_arr_int_scaled, /dimensions)
; ; Get the data type
; data_type_int = size (senz_arr_int_scaled, /type)
; ; Construct the output file name
; out_file_name_str = senz_prefix_str + "_" + $
;                     strtrim (string (dimm_arr [0]), 1) + "_" + $
;                     strtrim (string (dimm_arr [1]), 1) + "_" + $
;                     strtrim (string (data_type_int), 1) + ".dat"
; 
; ; Write data to output binary file
; openw, lun, out_file_name_str, /get_lun
; writeu, lun, temporary (senz_arr_int_scaled)
; free_lun, lun

senz_arr = make_array (dim0_int, dim1_int, TYPE=4)

openr, lun, senz_filep_str, /get_lun
readu, lun, senz_arr
free_lun, lun

; Filter fill values
idx = where (senz_arr LT -900.0)
if n_elements (idx) GT 1 then begin
    senz_arr [idx] = -999.0
end

senz_arr_int_scaled = FIX (abs (temporary (senz_arr)) * 100.0)
if n_elements (idx) GT 1 then begin
    senz_arr_int_scaled [idx] = 180 * 100
end

; Write data to output binary file
openw, lun, senz_filep_str, /get_lun
writeu, lun, senz_arr_int_scaled
free_lun, lun

; ;- Close the file
; h5f_close, file_id

END

