#!/bin/bash

# ============================================================================
# Purpose: This script filters out of range sensor zenith angle values in a 
#     sensor zenith angle array. This script assumes that the given sensor 
#     zenith angle data have been scaled by 100.
# 
# Input parameters:
# sensor zenith angle binary file - The sensor zenith angle data in a binary 
#     file. It is assumed that the file name has the following format:
#     <string>_<nr columns>_<nr rows>_<IDL data type>.dat
# 
# Authors: Liam.Gumley@ssec.wisc.edu, Willem.Marais@ssec.wisc.edu
# Date: 07/22/2011 
# ============================================================================

if [ $# -ne 2 ]; then
    echo "Usage: "
    echo "    "$(basename $0)" <sensor zenith angle binary file> <scale value>"
    
    exit 1
fi

szenangle_bin_file=$1
scale_value=$2
szena_bin_basename=$(basename $szenangle_bin_file .dat)

nr_cols=$(echo $szena_bin_basename | cut -d"_" -f 2)
nr_rows=$(echo $szena_bin_basename | cut -d"_" -f 3)
dtype=$(echo $szena_bin_basename | cut -d"_" -f 4)

cat > runidl << EOF
condition_szenangle_bin, '$szenangle_bin_file', $nr_cols, $nr_rows, $dtype, $scale_value
exit
EOF

if [ "$MIPS_DEBUG" == "YES" ]; then
    cat runidl
    $IDL_CMD runidl &> idl_output.txt
    idl_rtn=$?
    cat idl_output.txt
else
    $IDL_CMD runidl &> idl_output.txt
    idl_rtn=$?
fi

grep --ignore-case "Error" idl_output.txt &> /dev/null
if [ $? -eq 0 ] || [ $idl_rtn -ne 0 ]; then
    echo "(ERROR)[E4] IDL script 'condition_szenangle_bin.pro' could not condition file "$(basename $szenangle_bin_file)"."
    echo "========= IDL script ========="
    cat runidl
    echo "========= IDL output ========="
    cat idl_output.txt
    
    exit 1
fi


