#!/bin/bash

# Load the sensor processing constants
if [ -z $MIPS_SENSOR_CONF ]; then
    echo "(ERROR)[Exx] The processing constants configuration file "$MIPS_SENSOR_CONF" does not exist"
    exit 1
fi
source $MIPS_SENSOR_CONF

if [ $# -ne 2 ]; then
    echo "Usage: "
    echo "    "$(basename $0)" <tilenr> <out file path>"
    exit 1
fi

tilenr=$1
out_file=$2

ul_lr_coord_txt_file="ul_lr_coord_txt_file.txt"
/bin/bash $MIPS_HOME/scripts/auxiliary/get_normal_tile_ul_lr_coord.bash $tilenr 0 $ul_lr_coord_txt_file
# If an error occured, exit immediately.
if [ $? -ne 0 ]; then
    exit 1
fi

ul_lat=$(grep 'UL_LAT' $ul_lr_coord_txt_file | cut -d"=" -f 2)
ul_lon=$(grep 'UL_LON' $ul_lr_coord_txt_file | cut -d"=" -f 2)
lr_lat=$(grep 'LR_LAT' $ul_lr_coord_txt_file | cut -d"=" -f 2)
lr_lon=$(grep 'LR_LON' $ul_lr_coord_txt_file | cut -d"=" -f 2)

ul_coord=$ul_lon,$ul_lat
lr_coord=$lr_lon,$lr_lat

grid_size_txt_file="grid_size_txt_file.txt"
if [ "$MIPS_DEBUG" == "YES" ]; then
    echo "[DEBUG] Executing the following:"
    echo "    "/bin/bash $MIPS_HOME/scripts/auxiliary/calc_grid_size.bash $ul_coord $lr_coord 'Normal' $MIPS_PC_PIXEL_RESOL $grid_size_txt_file
fi
/bin/bash $MIPS_HOME/scripts/auxiliary/calc_grid_size.bash $ul_coord $lr_coord 'Normal' $MIPS_PC_PIXEL_RESOL $grid_size_txt_file
# If an error occured, exit immediately.
if [ $? -ne 0 ]; then
    exit 1
fi

nr_cols=$(grep 'COLS' $grid_size_txt_file | cut -d"=" -f 2)
nr_rows=$(grep 'ROWS' $grid_size_txt_file | cut -d"=" -f 2)

cat > runidl << EOF
create_normal_tile_tiff, '$out_file', $nr_cols, $nr_rows
exit
EOF

if [ "$MIPS_DEBUG" == "YES" ]; then
    cat runidl
    $IDL_CMD runidl &> idl_output.txt
    idl_rtn=$?
    cat idl_output.txt
else
    $IDL_CMD runidl &> idl_output.txt
    idl_rtn=$?
fi

grep -i "Error" idl_output.txt &> /dev/null
if [ $? -eq 0 ] || [ $idl_rtn -ne 0 ]; then
    echo "(ERROR)[E16] The IDL script 'create_normal_tile_tiff.pro' failed."
    cat idl_output.txt
    exit 1
fi

rm -f idl_output.txt runidl $ul_lr_coord_txt_file $grid_size_txt_file

