#!/bin/bash

if [ $# -ne 4 ]; then
    echo "Usage:"
    echo $(basename $0)" <event file list> <event file type> <band combination> <output file>"
    
    exit 1
fi

event_file_lst=$1
event_file_type=$2
band_comb=$3
output_file=$4

rm -f $output_file

# Find unique list of tile numbers
event_file_filt_lst=$(mktemp --tmpdir=$PWD -u "event_file_filtXXXXXXXX")
tile_lst=$(mktemp --tmpdir=$PWD -u "tile_lstXXXXXXXX")
date_lst=$(mktemp --tmpdir=$PWD -u "date_lstXXXXXXXX")
unique_tile_lst=$(mktemp --tmpdir=$PWD -u "unique_tile_lstXXXXXXXX")
unique_date_lst=$(mktemp --tmpdir=$PWD -u "unique_date_lstXXXXXXXX")
tmp_output_file=$(mktemp --tmpdir=$PWD -u "tmp_outputXXXXXXXX")

eg_file_path_str=$(head -n 1 $event_file_lst)
if [ -z "$eg_file_path_str" ]; then
    echo '' > $output_file
    exit 0
fi
eg_dir_path_str=$(dirname $eg_file_path_str)
eg_dir_path_str=$(dirname $eg_dir_path_str)

if [ $eg_dir_path_str != "." ]; then
    grep $band_comb $event_file_lst | sed "s^$eg_dir_path_str^^g" > $event_file_filt_lst
else
    grep $band_comb $event_file_lst > $event_file_filt_lst
fi

# Make a list of all the tile numbers
cat $event_file_filt_lst | awk '{split ($1, arr, "/"); print arr [2]}' > $tile_lst
# Sort the list of tile numbers and make the unique list of tile numbers
sort $tile_lst | uniq > $unique_tile_lst

# Make a list of all the date values
cat $event_file_filt_lst | awk '{split ($1, arr, "."); print arr [4]}' > $tile_lst
# Sort the list of tile numbers and make the unique list of tile numbers
sort $tile_lst | uniq > $unique_date_lst

# Reuse tile_lst file
for datenr_str in $(cat $unique_date_lst); do
    grep $datenr_str $event_file_lst | grep $band_comb > $date_lst
    for tilenr_str in $(cat $unique_tile_lst); do
        grep $tilenr_str $date_lst > $tile_lst
        /bin/bash $MIPS_HOME/scripts/auxiliary/sort_comp_img_filelst.bash $tile_lst $tmp_output_file 6
        tail -n 1 $tmp_output_file 2> /dev/null >> $output_file
        rm -f $tmp_output_file
    done
done

rm -f $event_file_filt_lst $tile_lst $unique_tile_lst $tmp_output_file $unique_date_lst

