#!/bin/bash

if [ $# -ne 6 ]; then
    echo "Usage: "
    echo "    "$(basename $0)" <geo file> <bin file> <fill value> <latitude threshold> <pixel shift> <sat name>"

    exit 1
fi

geo_file=$1
bin_file=$2
fill_value=$3
lat_threshold=$4
pixel_shift=$5
sat_name=$6

bin_file_basename=$(basename $bin_file ".dat")

# Get the column, row and data type values
nr_col=$(echo $bin_file_basename | cut -d"_" -f 2)
nr_row=$(echo $bin_file_basename | cut -d"_" -f 3)
type_val=$(echo $bin_file_basename | cut -d"_" -f 4)

cat > runidl << EOF
bin_file_array = ['$bin_file']
filter_polar_data_edge, '$geo_file', bin_file_array, 1, $fill_value, '$sat_name', $nr_col, $nr_row, $type_val, $lat_threshold, $pixel_shift
exit
EOF

if [ "$MIPS_DEBUG" == "YES" ]; then
    cat runidl
    $IDL_CMD runidl &> idl_output.txt
    idl_rtn=$?
    cat idl_output.txt
else
    $IDL_CMD runidl &> idl_output.txt
    idl_rtn=$?
fi

grep --ignore-case "Error" idl_output.txt &> /dev/null
if [ $? -eq 0 ] || [ $idl_rtn -ne 0 ]; then
    echo "(ERROR)[E89] IDL script 'filter_polar_data_edge.pro' could not filter file $bin_file."
    echo "========= IDL script ========="
    cat runidl
    echo "========= IDL output ========="
    cat idl_output.txt
    
    exit 1
fi

grep --ignore-case "Warning" idl_output.txt &> /dev/null
if [ $? -eq 0 ]; then
    warning_str=$(grep --ignore-case "Warning" idl_output.txt)
    echo "(WARNING)[W3] IDL script asc_desc_filt_binfile: "
    echo "    "$warning_str
fi


