#!/bin/bash

if [ $# -ne 6 ]; then
    echo $(basename $0)" <UL lon,lat> <LR lon,lat> <Resol> <Proj type> <MPP output> <GPD output>"
    exit 1
fi

ul_lat_lon=$1
lr_lat_lon=$2
resol_str=$3
proj_type=$4
mpp_out_file=$5
gpd_out_file=$6

grid_info_file=$(mktemp --tmpdir=$PWD grid_infoXXXXXX)

/bin/bash $MIPS_HOME/scripts/auxiliary/calc_grid_size.bash \
    $ul_lat_lon $lr_lat_lon $proj_type $resol_str $grid_info_file
if [ $? -ne 0 ]; then
    exit 1
fi

ul_lon_str=$(grep UL_LON $grid_info_file | awk '{print $3}')
ul_lat_str=$(grep UL_LAT $grid_info_file | awk '{print $3}')
nr_cols_str=$(grep COLS $grid_info_file   | awk '{print $2}')
nr_rows_str=$(grep ROWS $grid_info_file   | awk '{print $2}')

cat $MIPS_HOME/templates/normal_ms2gt_templ.mpp > $mpp_out_file
cat $MIPS_HOME/templates/normal_ms2gt_templ.gpd > $gpd_out_file

sed -i "s/MMP_FILE_NAME/$mpp_out_file/g" $gpd_out_file
sed -i "s/RES/$resol_str/g" $gpd_out_file
sed -i "s/GRID_WIDTH/$nr_cols_str/g" $gpd_out_file
sed -i "s/GRID_HEIGHT/$nr_rows_str/g" $gpd_out_file

case $proj_type in
    "Normal" )
        sed -i "s/PROJ_NAME/CYLINDRICAL EQUIDISTANT/g" $mpp_out_file
        sed -i "s/MAP_REF_LAT/0.0/g" $mpp_out_file
        sed -i "s/MAP_REF_LON/0.0/g" $mpp_out_file
        sed -i "s/MAP_EQUA_RAD/6371007.181/g" $mpp_out_file
        sed -i "s/MAP_POLAR_RAD/6371007.181/g" $mpp_out_file
        sed -i "s/MAP_ORG_LAT/$ul_lat_str/g" $mpp_out_file
        sed -i "s/MAP_ORG_LON/$ul_lon_str/g" $mpp_out_file
    ;;
     
    * )
    ;;
esac

rm -f $grid_info_file

