#!/bin/bash

usage_str=$(basename $0)" <HDF5 GMTCO or GMODO or GITCO> <latitude prefix> <longitude prefix> <sensor zenith angle prefix>"
if [ $# -ne 4 ]; then
    echo "(ERROR) Usage: "
    echo "    "$usage_str
    
    exit 1
fi

hdf5_file=$1
lat_prefix_str=$2
lon_prefix_str=$3
senz_prefix_str=$4

hdf5_basename_str=$(basename $hdf5_file)
hdf5_geo_prefix_str=$(echo $hdf5_basename_str | cut -d"_" -f 1)

dataset_path_str=""
case $hdf5_geo_prefix_str in 
    "GMTCO" )
        dataset_path_str="/All_Data/VIIRS-MOD-GEO-TC_All"
    ;;
    
    "GMODO" )
        dataset_path_str="/All_Data/VIIRS-MOD-GEO_All"
    ;;
    
    "GITCO" )
        dataset_path_str="/All_Data/VIIRS-IMG-GEO-TC_All"
    ;;
esac

txt_rtrn_str=$($MIPS_HOME/bin/h5dump -H -d $dataset_path_str"/Latitude" $hdf5_file | grep "SIMPLE")
dim1_str=$(echo $txt_rtrn_str | awk '{print $5}' | sed 's/,//')
dim0_str=$(echo $txt_rtrn_str | awk '{print $6}')

lat_bin_filep_str=$lat_prefix_str"_"$dim0_str"_"$dim1_str"_4.dat"
lon_bin_filep_str=$lon_prefix_str"_"$dim0_str"_"$dim1_str"_4.dat"
sen_bin_filep_str=$senz_prefix_str"_"$dim0_str"_"$dim1_str"_2.dat"

$MIPS_HOME/bin/h5dump -d $dataset_path_str"/Latitude" -b LE -o $lat_prefix_str"_"$dim0_str"_"$dim1_str"_4.dat" $hdf5_file
$MIPS_HOME/bin/h5dump -d $dataset_path_str"/Longitude" -b LE -o $lon_prefix_str"_"$dim0_str"_"$dim1_str"_4.dat" $hdf5_file
$MIPS_HOME/bin/h5dump -d $dataset_path_str"/SatelliteZenithAngle" -b LE -o $senz_prefix_str"_"$dim0_str"_"$dim1_str"_2.dat" $hdf5_file

cat > runidl << EOF
viirs_geodata_filter, '$lat_bin_filep_str', '$lon_bin_filep_str', '$sen_bin_filep_str', $dim0_str, $dim1_str
exit
EOF

if [ "$MIPS_DEBUG" == "YES" ]; then
    cat runidl
    $IDL_CMD runidl &> idl_output.txt
    idl_rtn=$?
    cat idl_output.txt
else
    $IDL_CMD runidl &> idl_output.txt
    idl_rtn=$?
fi

grep -i "Error" idl_output.txt &> /dev/null
if [ $? -eq 0 ] || [ $idl_rtn -ne 0 ]; then
    # echo "(ERROR)[Exx] IDL script 'hdf5_viirs_geodata_to_bin' could not convert file "$(basename $hdf5_file)" into binary file."
    echo "(ERROR)[Exx] IDL script 'viirs_geodata_filter' could not convert file "$(basename $hdf5_file)" into binary file."
    echo "========= IDL script ========="
    cat runidl
    echo "========= IDL output ========="
    cat idl_output.txt
    
    exit 1
fi


