#!/bin/bash

if [ $# -ne 3 ]; then
    echo $(basename $0)" <latitude bin file> <longitude bin file> <output text file>"
    exit 1
fi

lat_bin_file=$1
lon_bin_file=$2
out_file=$3

# The assumption is that the binary files have the following file formats:
# <prefix>_<nr of columns>_<nr of rows>_<IDL data type>.dat

bsn_lat_bin_file=$(basename $lat_bin_file)
nr_cols=$(echo $bsn_lat_bin_file | cut -d"_" -f 2)
nr_rows=$(echo $bsn_lat_bin_file | cut -d"_" -f 3)
idl_type=$(echo $bsn_lat_bin_file | cut -d"_" -f 4 | cut -d"." -f 1)

cat > runidl << EOF
latlon_bin_geo_ul_lr, '$lat_bin_file', '$lon_bin_file', $nr_cols, $nr_rows, $idl_type, '$out_file'
exit
EOF

if [ "$MIPS_DEBUG" == "YES" ]; then
    cat runidl
    $IDL_CMD runidl &> idl_output.txt
    idl_rtn=$?
    cat idl_output.txt
else
    $IDL_CMD runidl &> idl_output.txt
    idl_rtn=$?
fi

grep -i "Error" idl_output.txt &> /dev/null
if [ $? -eq 0 ] || [ $idl_rtn -ne 0 ]; then
    echo "(ERROR)[Exx] IDL script 'latlon_bin_geo_ul_lr' failed to extract the UL and LR coordinates."
    echo "========= IDL script ========="
    cat runidl
    echo "========= IDL output ========="
    cat idl_output.txt
    
    exit 1
fi

