#!/bin/bash

# ============================================================================
# TODO
# ============================================================================

# Check for MIPS_HOME environment variable
if [ -z "$MIPS_HOME" ]; then
  echo "Environment variable MIPS_HOME is not set"
  exit 1
fi

if [ $# -lt 4 ]; then
    echo "(ERROR) Usage: "
    echo "    "$(basename $0)" <GMTCO or GMODO file> <SVM and/or SVI files> <CREFL lres> <CREFL hres>"
    exit 1
fi

# First get the geolocation file
fil_geo=$1
shift 1
# Get the number of arguments that remains after the geolocation file
nr_arg=$#
# Get the SVM and SVI files that are passed, which are before the CREFL output file names
fil_lres_lst=""
fil_hres_lst=""
nr_arg_svm_svi=$(echo "$nr_arg - 2" | bc)
seq_val_arr=$(eval echo {1..$nr_arg_svm_svi})

for seq_val in $seq_val_arr; do
    bsname_file_str=$(basename $1)
    file_start_name_str=$(echo $bsname_file_str | cut -c1-3)
    
    if [ "$file_start_name_str" == "SVM" ]; then
        fil_lres_lst="$1 $fil_lres_lst"
    else
        fil_hres_lst="$1 $fil_hres_lst"
    fi
    
    shift 1
done

# Get the CREFL output file names
ref_lres=$1
ref_hres=$2

if [ "$MIPS_DEBUG" == "YES" ]; then 
    echo "fil_geo: "$fil_geo
    echo "fil_lres_lst: "$fil_lres_lst
    echo "fil_hres_lst: "$fil_hres_lst
    echo "ref_lres: "$ref_lres
    echo "ref_hres: "$ref_hres
fi

# If the output files already exist, do not continue with the processing of the 
# input L1B data.
if [ -e $ref_hres ] && [ -e $ref_lres ]; then
    exit 0
fi

#-------------------------------------------------------------------------------
# EXECUTE CREFL ALGORITHM OVER INPUT L1B DATA
#-------------------------------------------------------------------------------
# Create soft links to standard filenames expected by crefl

# Set an environment variable for the CREFL algorithm
export ANCPATH=$MIPS_HOME/bin

# Execute CREFL for LRES data
if [ ! -z "$fil_lres_lst" ]; then
    echo
    echo "(Creating LRES corrected reflectance in "$ref_lres")"
    $MIPS_HOME/bin/crefl.1.7.1 viirs --verbose --overwrite --of=$ref_lres $fil_geo $fil_lres_lst

    if [ $? -ne 0 ]; then
        echo "(ERROR)[Exx] CREFL failed to process LRES L1B data"
        exit 1
    fi
fi

# Execute CREFL for HRES data
if [ ! -z "$fil_hres_lst" ]; then
    echo
    echo "(Creating HRES corrected reflectance in "$ref_hres")"
    $MIPS_HOME/bin/crefl.1.7.1 viirs --verbose --overwrite --of=$ref_hres $fil_geo $fil_hres_lst

    if [ $? -ne 0 ]; then
        echo "(ERROR)[Exx] CREFL failed to process HRES L1B data"
        exit 1
    fi
fi

# Remove temporary files
rm -f idl_output.txt idlsave.pro runidl

