#!/bin/bash

# ============================================================================
# Purpose: This script is used to sort MIPS files according to a specific 
#     field. The format of a composite image file is as follows, where each 
#     field is separated by a '.' character:
#     
#     <tile number>.<satellite name>.<year-date>.<band combination>.<composite level>.png
#     
#     To sort files that have the same naming convention as the one above, a 
#     field can be chosen according to which the files will be sorted.
# 
# Input parameters:
#     1. Input text file. All the file names that need to be sorted must be 
#        be in a text file. Each file name must appear on a new line.
#     2. Output text file. The sorted file names will be copied to this text 
#        file. 
#     3. The field number according to which the file names must be sorted.
#     
# Authors: Liam.Gumley@ssec.wisc.edu, Willem.Marais@ssec.wisc.edu
# Date: 07/22/2011 
# ============================================================================

if [ $# -ne 3 ]; then
    echo "Usage: "
    echo "    "$(basename $0)" <input file name> <output file name> <field number>"
    
    exit 1
fi

in_file=$1
out_file=$2
field_nr=$3

tmp_file=$(mktemp)
tmp_two_file=$(mktemp)

OLD_IFS=$IFS
IFS=$(echo -e '\n\b')
for file_str in $(cat $in_file); do
    file_base_name=$(basename $file_str)
    field_str=$(echo $file_base_name | cut -d'.' -f $field_nr)
    
    echo "$field_str""@""$file_str" >> $tmp_file
done
IFS=$OLD_IFS

cp $tmp_file $tmp_two_file
# Sort according to numerical numbers
sort -n $tmp_two_file > $tmp_file

OLD_IFS=$IFS
IFS=$(echo -e '\n\b')
for line_str in $(cat $tmp_file); do
    file_str=$(echo $line_str | cut -d"@" -f 2)
    
    echo $file_str >> $out_file
done
IFS=$OLD_IFS

rm -f $tmp_file $tmp_two_file

