# ============================================================================
# MIPS BASH (default) source file - For MODIS sensor
# 
# Authors: Liam.Gumley@ssec.wisc.edu, Willem.Marais@ssec.wisc.edu
# Date: 10/12/2011
# ============================================================================

# ============================================================================
# DO NOT DELETE ANY OF THE VARIALBE NAMES IN THIS FILE. ONLY CHANGE THE VALUES 
# OF THE VARIALBES.
# ============================================================================

# This variable points to the directory where the configuration files are
# archived. 
export MIPS_CONF=$MIPS_HOME/config

# TODO: Add documentation
export MIPS_SENSOR_CONF=$MIPS_CONF/modis_process_constants.bash
export MIPS_MOSAIC_CONF=$MIPS_CONF/modis_mosaic.conf

# ----------------------------------------------------------------------------
# The following environmental variable alter the output of the MIPS 
# processing system.
# ----------------------------------------------------------------------------

# The following environmental variable points to the filesystem path where the 
# subset configuration file is. Refer to the confiruration file for more 
# information about it. 
export MIPS_SUBSET_CONF=$MIPS_CONF/modis_subsets.conf
# This subset configuration file will be regarded as a read-only file.
export MIPS_RO_SUBSET_CONF=$MIPS_CONF/modis_subsets_readonly.conf
# If a script fails during the processing of L1B data, there might be event 
# files that are undeleted. These event files are left unaccounted for - if 
# MIPS wants to process the event file, the L1B files corrosponding to the 
# event file might not be available. Such stale event files must be 
# removed. 
export MIPS_LIFET_EVENTF=5760 # 5760 minutes == 4 days
# MIPS includes an utility script, called clean_tile_dir.sh, that removes tile 
# images and meta files which are older than specified configuration values. 
# The following environmental variables defines the lifetime of the 
# intermediate products (subsets, KML files, polar mosaic files). The value 
# MUST be in minutes.
export MIPS_LIFET_INTERM=5760 # 5760 minutes == 4 days
# This environmental variable defined the lifetime of the products (subsets, 
# KML files, polar mosaic files). The value MUST be in minutes.
export MIPS_LIFET_PRODUC=20160 # 20160 minutes == 2 weeks
# The MIPS software has the capability of remove pixels which have high sensor
# zenith angle values. Pixels with high sensor zenith angle values are of lower
# quality than low sensor zenith angle values. 
export MIPS_FILT_HSENZ_ANGL=60
# If the configuration file defined by the variable MIPS_BAND_COMB_CONF does
# not exist, the band combination defined by the following environmental
# variable will be used. This applies for both non-polar and polar data.
export MIPS_DEFAULT_BANDCOMB="01_04_03_01_01"
# A GeoTIFF version of the both the tile and polar tiles images can be created 
# in conjunction with the PNG image. If this varialbe is equal to 'YES', then 
# GeoTIFF images will be created.
export MIPS_TILE_GEOTIFF_BL="YES"
# By default Arctic polar mosaic images are from +41.1 degrees to +90 degrees.
# The following variable can be used to set from which latitude the mosaic
# images should start.
export MIPS_NORTH_POLARM_LAT=70
# By default Antarctic polar mosaic images are from -41.1 degrees to -90
# degrees.  The following variable can be used to set from which latitude the
# mosaic images should start.
export MIPS_SOUTH_POLARM_LAT=-70
# The following variable sets the default output resolution (in meters) of the
# polar mosaic images. The number must be a natural number that is devisable by
# 250.
export MIPS_POLAR_MOSIAC_RESOL=250
# Set the following variable to 'YES' if a 1000 meter resolution polar mosaic 
# image should be created.
export MIPS_POLAR_MOSIAC_1KM="NO"
# Set the following variable to 'YES' if a 4000 meter resolution polar mosaic 
# image should be created.
export MIPS_POLAR_MOSIAC_4KM="NO"
# The following variable determine the output resolution of the global mosaic 
# images. The number must be a natural number that is devisable by 250.
export MIPS_GLOBAL_MOSAIC_RESOL=1000
# The linear enhancement coefficients that are used for the RGB composite images 
# are defined in the following configuration files. For each satellite there is 
# a separate file.
export MIPS_TERRA_LENCH_FILE=$MIPS_CONF/modis_terra_lench.conf
export MIPS_AQUA_LENCH_FILE=$MIPS_CONF/modis_aqua_lench.conf
# The command parameters that are used by ImageMagick to do image sharping on 
# the final output images, are defined by the following parameter. Refer 
# to the ImageMagick user manual for an explanation of the parameters.
export MIPS_IMG_SHARPEN_STR="-sigmoidal-contrast 3,50% -modulate 100,125,100 -gamma 1.1 -unsharp 0"
# The following variables control ImageMagick. These variables are used to control 
# how much memory and diskspace are used by ImageMagick, and also what 
# directory should be used the temporary directory.
# WARNING: When ImageMagick is used by the global and polar mosiac scripts, 
# the amount of memory (disk and main memory) that is used will in the order 
# of 10GB.
# # The disk space limit for ImageMagick in bytes.
# export MAGICK_DISK_LIMIT="50gb"
# # The memory limit for ImageMagick in bytes.
# export MAGICK_MEMORY_LIMIT="2gb"
# # The memory map limit for ImageMagick in bytes.
# export MAGICK_MAP_LIMIT="2gb"
# # Set the directory path where ImageMagick can store it's temporary files.
# export MAGICK_TEMPORARY_PATH="$MIPS_HOME/scratch/image.magick"

# ----------------------------------------------------------------------------
# The folowing environmental variables defined the filesystem locations where 
# the MIPS products are archived. Each of the following variable *MUST* point 
# to valid filesystem direction paths. 
# ----------------------------------------------------------------------------

# The image tiles will be archived in the directory which is specified by this
# environmental variable. Note that this directory size will be in the order of
# hundreds of gigabytes over a period of time.
export MIPS_TILE_DIR=$MIPS_HOME/products/modis/tiles
# The polar image tiles are archived in directory separate from the normal 
# image tiles. This environment variable point to the directory where 
# both North and South polar image tiles are archived.
export MIPS_POLR_TILE_DIR=$MIPS_HOME/products/modis/polartiles
# The GE (Google Earth) KML files that are generated by MIPS, are archived 
# in the directory set by this environmental variable.
export MIPS_KML_DIR=$MIPS_HOME/products/modis/kml
# The custom subset images are archived in the directory set by this
# environmental variable.
export MIPS_SUBSET_DIR=$MIPS_HOME/products/modis/subsets
# The mosaic images are archived in the directory set by this environmental
# variable.
export MIPS_MOSAIC_DIR=$MIPS_HOME/products/modis/mosaic
# For each L1B granule that is processed by MIPS, an unprojected 1KM resolution 
# image is created.
export MIPS_GRAN_IMG_DIR=$MIPS_HOME/products/modis/granimg

# ----------------------------------------------------------------------------
# The following environmental variables are used during the processing of the 
# KML files. Change these environmental variable values to customize the KML 
# files.
# ----------------------------------------------------------------------------

# This variable must equal to the URL which points to the local web server name 
# directory where the KML files can be accessed.
# TODO: The web directory that is refered to by this variable, must have the following 
#       two files listed: (.....) when MIPS are processing incoming L1B data.
export MIPS_KML_URL="http://luiperd.ssec.wisc.edu/products/modis/kml/"
# The name of the geographical site over which the global KML files will be 
# centered. The name must be all capital letters. 
export MIPS_SITE_NAME="SSEC"    # Note: all capital letters, no spaces allowed
# The central latitude value of the site's (MIPS_SITE_NAME) geographic location.
export MIPS_SITE_LAT="43.07072"
# The central longitude value of the site's (MIPS_SITE_NAME) geographic location.
export MIPS_SITE_LON="-89.40685"

# ----------------------------------------------------------------------------
# The following environmental variables alter the diagnotistic output 
# messages of the MIPS processing scripts.
# ----------------------------------------------------------------------------

# If this variable is equal to YES, the MIPS processing script will print
# extra information to the terminal output which can be used to debug the
# processing scripts. 
export MIPS_DEBUG="NO"

# ----------------------------------------------------------------------------
# The following environment variables were set before the final relaese of 
# the MIPS software. Only change these following variables when it is 
# ABSOLUTELY necessary.
# ----------------------------------------------------------------------------

# The FL_DIR environment variable point to the Fawlty IDL interpreter directory
# export FL_DIR=$MIPS_HOME/fl/fl_0.79.25
export FL_DIR=$MIPS_HOME/fl/fl_0.79a
# Add to the BASH variable, PATH, the filesystem paths of the primary 
# MIPS scripts and the binary executables that are used by MIPS
export PATH=$HOME/Apps/bin:$MIPS_HOME/scripts:$MIPS_HOME/bin:$FL_DIR/bin:/usr/local/bin:$PATH
# The IDL script, to which this environmental variable points to, is first executed by 
# the IDL interpreter before any another IDL procedure file is executed. 
export IDL_STARTUP=$MIPS_HOME/idl/idl_startup.pro
# The IDL interpreter command that is to be used is determined by this variable. Any 
# IDL interpreter options can be included in the variable value. The IDL_CMD variable 
# will most likely be equal to one of the following values in the following list:
export IDL_CMD="fl"
# The commercial IDL interpreter, developed by ITT
# (http://www.ittvis.com/ProductServices/IDL.aspx), needs either a filesystem
# path to a license file or a license server DNS name. If the free software IDL
# interpreter FL is used, it is not necessary to set the value of this
# variable.
export LM_LICENSE_FILE=""
# The false color and true color band combinations that are used for making
# tile images for NON-POLAR regions, are defined in this file.  Refer to the
# config file for more information about it. 
export MIPS_BAND_COMB_CONF=$MIPS_CONF/modis_tile_bands.conf
# The false color and true color band combinations that are used for making
# tile images for POLAR regions, are defined in this file.  Refer to the
# config file for more information about it. 
export MIPS_BAND_COMB_POLAR_CONF=$MIPS_CONF/modis_polar_tile_bands.conf
# The different resolutions where in the sensor bands are available in, 
# are defined in the configuration file defined by this environmental 
# variable. 
export MIPS_BAND_SPEC_CONF=$MIPS_CONF/modis_band_specs.conf
# Non-polar tile numbers that should NOT be processed by MIPS, are listed 
# in the configuration file defined by this environmental variable.
export MIPS_TEXCLUDE_CONF=$MIPS_CONF/exclude_tiles.conf
# Polar tile numbers that should be NOT be processed by MIPS, are listed 
# in the configuration file defined by this environmental variable. 
export MIPS_PTEXCLUDE_CONF=$MIPS_CONF/exclude_polar_tiles.conf
