#!/bin/bash

# ============================================================================
# MIPS MODIS granule processor wrap BASH script
# 
# The main script through which MODIS L1B data are processed, is through
# process_granule_tiles_modis.bash. The main script depends on several input
# parameters, therefore it is cumbersome to execute the main script. This
# script is wrapper script for the main script. Only the L1B file names have to
# be given to this script, and it does not depend on other input parameters. It
# determines the necessary input parameters which are given to the main script.
# 
# Authors: Liam.Gumley@ssec.wisc.edu, Willem.Marais@ssec.wisc.edu
# Date: 07/22/2011
# ============================================================================

if [ -z "$MIPS_HOME" ]; then
    echo "Environment variable MIPS_HOME is not set"
    exit 1
fi

# Echo command line
echo
echo "(Echoing command line)"
echo $(basename $0) $@

# Check number of arguments
if [ $# -ne 4 ]; then
    echo "(ERROR) Usage:"
    echo "    "$(basename $0)" file_1km file_hkm file_qkm file_geo"
    echo "where"
    echo "file_1km = MODIS L1B 1000 meter HDF4 file"
    echo "file_hkm = MODIS L1B 500 meter HDF4 file"
    echo "file_qkm = MODIS L1B 250 meter HDF4 file"
    echo "file_geo = MODIS L1B geolocation HDF4 file"
    
    exit 1
fi

# Get arguments
file_1km=$1
file_hkm=$2
file_qkm=$3
file_geo=$4

# Get the satellite name, the date and time metadata
bsn_file_1km=$(basename $file_1km)
satcode=$(echo $bsn_file_1km | cut -c1-3 | tr "[:upper:]" "[:lower:]")
if [ "$satcode" == "mod" ]; then
    satname="terra"
else
    satname="aqua"
fi
year_str=$(echo $bsn_file_1km | cut -d"." -f 2 | cut -c2-5)
julday_str=$(echo $bsn_file_1km | cut -d"." -f 2 | cut -c6-8)
# Convert julian day to normal day value
yeardate_str=$(date -d "$year_str-01-01 +$julday_str days -1 day" "+%Y%m%d")
time_str=$(echo $bsn_file_1km | cut -d"." -f 3)

/bin/bash $MIPS_HOME/scripts/process_granule_tiles_modis.bash $file_1km $file_hkm $file_qkm $file_geo $satname \
                                                              $yeardate_str $time_str

# Exit with the exit return value of the process_granule_tiles_modis.bash script.
exit $?

