#!/bin/bash

# if [ -z "$MIPS_INSTALL_DIR" ]; then
#     echo "(ERROR) The environment variable MIPS_INSTALL_DIR is not defined."
#     exit 1
# fi

if [ -z "$MIPS_HOME" ]; then
    echo "(ERROR) The environment variable MIPS_HOME is not defined."
    exit 1
fi

if [ $# -ne 2 ]; then
    echo "(ERROR)"
    echo "    Usage: "$(basename $0)" <full path to base scratch directory> <log directory>"
    exit 1
fi

base_scratch_dir=$1
base_log_dir=$2

log_dir=$base_log_dir"/modis_aqua"
mkdir -p $log_dir

# Number of CPU cores used to parallel process the SDRs
NR_PROCESS_INT=8

# Get the full filesystem path to the script
FILEP_STR=$(readlink -f $0)
SCRIPT_DIR=$(dirname $FILEP_STR)
# Get the directory of where the VIIRS SDR files are
DATA_DIR_STR=$(dirname $FILEP_STR)"/modis_aqua"

# =================================================================================================================
# Process test L1B granules
# =================================================================================================================
echo "(3.1 Processing test L1B granules)"

# Get the list of geo files, and process each one
find $DATA_DIR_STR/ -name a1.13049.*.geo.hdf -type f -print  | \
    xargs -P $NR_PROCESS_INT -n 1 $SCRIPT_DIR/test_modis_task.bash $base_scratch_dir "aqua" $log_dir

# =================================================================================================================
# Create KML files
# =================================================================================================================
echo "(3.2 Processing KML files)"

# Load MIPS configuration
source $MIPS_HOME/scripts/environment/default/mips_modis_env.bash

cd $base_scratch_dir
/bin/bash $MIPS_HOME/scripts/process_kml.bash &> $log_dir"/modis_aqua_test_kml.log"
cd - &> /dev/null

# =================================================================================================================
# Create subsets
# =================================================================================================================
echo "(3.3 Processing subset files)"

cd $base_scratch_dir
/bin/bash $MIPS_HOME/scripts/process_subsets.bash &> $log_dir"/modis_aqua_test_subsets.log"
cd - &> /dev/null

# =================================================================================================================
# Check if there were any errors
# =================================================================================================================
grep "ERROR" $log_dir"/"* &> /dev/null
if [ $? -eq 0 ]; then
    echo "MODIS aqua test failed."
    
    # Move tar-ed scratch directory files into the log directory
    mv $base_scratch_dir/*.tar $log_dir/
    
    cd $base_log_dir
    tar_filen_str=$PWD"/modis_aqua_log_files_"$(date +"%Y%m%d_%H%M")".tar.bz2"
    tar cjf $tar_filen_str "modis_aqua"
    cd - &> /dev/null
    
    echo "Email the file $tar_filen_str to Willem.Marais@ssec.wisc.edu. This compressed tar file contains the log files. The log files will be used to diagnose the error."
else
    echo 'MODIS aqua test passed!'
fi
