#!/bin/bash

if [ -z "$MIPS_HOME" ]; then
    echo "(ERROR) The environment variable MIPS_HOME is not defined."
    exit 1
fi

if [ $# -ne 4 ]; then
    echo "(ERROR)"
    echo "    Usage: "$(basename $0)" <base scratch directory> <terra | aqua> <log directory> <file path to geolocation file>"
    exit 1
fi

base_scratch_dir=$1
sat_name_str=$2
log_dir=$3
geo_file_path_str=$4

FILEP_STR=$(readlink -f $0)
DATA_DIR_STR=$(dirname $FILEP_STR)"/modis_"$sat_name_str

# Load MIPS configuration
source $MIPS_HOME/scripts/environment/default/mips_modis_env.bash

# Get the date and time information.
geo_file_str=$(basename $geo_file_path_str)

sat_str=$(echo $geo_file_str | cut -d"." -f 1)
jdate_str=$(echo $geo_file_str | cut -d"." -f 2)
time_str=$(echo $geo_file_str | cut -d"." -f 3)
find_str=$sat_str"."$jdate_str"."$time_str

lres_filep_str=$(find $DATA_DIR_STR/ -name $find_str".1000m.hdf" | tail -n 1)
mres_filep_str=$(find $DATA_DIR_STR/ -name $find_str".500m.hdf" | tail -n 1)
hres_filep_str=$(find $DATA_DIR_STR/ -name $find_str".250m.hdf" | tail -n 1)

date_str="20130218"

if [ "$sat_str" == "t1" ]; then 
    sat_code_str="terra"
else
    sat_code_str="aqua"
fi

# Create a temporary scratch directory
scratch_dir_name_str=$sat_name_str"_"$date_str"_"$time_str"_scratch"
scratch_dir=$base_scratch_dir"/"$scratch_dir_name_str
mkdir -p $scratch_dir
# Go into the scratch directory
cd $scratch_dir

log_filep_str=$log_dir"/"$geo_file_str".log"

$MIPS_HOME/scripts/process_granule_tiles_modis.bash \
    $lres_filep_str \
    $mres_filep_str \
    $hres_filep_str \
    $geo_file_path_str \
    $sat_code_str \
    $date_str \
    $time_str &> $log_filep_str

grep "ERROR" $log_filep_str &> /dev/null
if [ $? -eq 0 ]; then 
    echo "(ERROR) Test failed on "$geo_file_str
    cd $base_scratch_dir
    tar cf $scratch_dir_name_str".tar" $scratch_dir_name_str
    
    exit 1
fi

# Go out the scratch directory
cd $base_scratch_dir
# Remove scratch directory
rm -r $scratch_dir
