#!/bin/bash

# if [ -z "$MIPS_INSTALL_DIR" ]; then
#     echo "(ERROR) The environment variable MIPS_INSTALL_DIR is not defined."
#     exit 1
# fi

if [ -z "$MIPS_HOME" ]; then
    echo "(ERROR) The environment variable MIPS_HOME is not defined."
    exit 1
fi

if [ $# -ne 2 ]; then
    echo "(ERROR)"
    echo "    Usage: "$(basename $0)" <full path to base scratch directory> <log directory>"
    exit 1
fi

base_scratch_dir=$1
base_log_dir=$2

log_dir=$base_log_dir"/viirs_npp"
mkdir -p $log_dir

# Number of CPU cores used to parallel process the SDRs
NR_PROCESS_INT=8

# Get the full filesystem path to the script
FILEP_STR=$(readlink -f $0)
SCRIPT_DIR=$(dirname $FILEP_STR)
# Get the directory of where the VIIRS SDR files are
DATA_DIR_STR=$(dirname $FILEP_STR)"/viirs_suomi_npp"

# =================================================================================================================
# Process test SDRs
# =================================================================================================================
echo "(3.1 Processing test SDRs)"

# -----------------------------------------------------------------------------------------------------------------
# Remove GMTCO files which have the same begin times, but have different processing times. 
# -----------------------------------------------------------------------------------------------------------------
tmp_flst=$(mktemp)
dub_tmp_flst=$(mktemp)
find $DATA_DIR_STR/ -name GMTCO_npp_d20130218_*h5 -type f -print > $tmp_flst

# Get the first part of the file names
for filep_str in $(cat $tmp_flst); do
    file_base_str=$(basename $filep_str | cut -d "_" -f 1-4)
    dirp_str=$(dirname $filep_str)
    
    echo $file_base_str >> $dub_tmp_flst
done

# Sort and get uniqe names
sort $dub_tmp_flst | uniq > $tmp_flst
rm -f $dub_tmp_flst

# Find duplicates and remove
for filep_str in $(cat $tmp_flst); do
    gmtco_filep_str=$(ls $dirp_str"/"$filep_str* | tail -n 1)
    
    echo $gmtco_filep_str >> $dub_tmp_flst
done

# -----------------------------------------------------------------------------------------------------------------
# Start processing
# -----------------------------------------------------------------------------------------------------------------
cat $dub_tmp_flst | xargs -P $NR_PROCESS_INT -n 1 $SCRIPT_DIR/test_viirs_suomi_npp_task.bash $base_scratch_dir $log_dir

# -----------------------------------------------------------------------------------------------------------------
# Remove temporary files
# -----------------------------------------------------------------------------------------------------------------
rm -f $tmp_flst $dub_tmp_flst

# =================================================================================================================
# Create KML files
# =================================================================================================================
echo "(3.2 Processing KML files)"

# Load MIPS configuration
source $MIPS_HOME/scripts/environment/default/mips_viirs_env.bash

cd $base_scratch_dir
/bin/bash $MIPS_HOME/scripts/process_kml.bash &> $log_dir"/viirs_npp_test_kml.log"
cd - &> /dev/null

# =================================================================================================================
# Create subsets
# =================================================================================================================
echo "(3.3 Processing subset files)"

cd $base_scratch_dir
/bin/bash $MIPS_HOME/scripts/process_subsets.bash &> $log_dir"/viirs_npp_test_subsets.log"
cd - &> /dev/null

# =================================================================================================================
# Check if there were any errors
# =================================================================================================================
grep "ERROR" $log_dir"/"* &> /dev/null
if [ $? -eq 0 ]; then
    echo "VIIRS NPP test failed."
    
    # Move tar-ed scratch directory files into the log directory
    mv $base_scratch_dir/*.tar $log_dir/
    
    cd $base_log_dir
    tar_filen_str=$PWD"/viirs_npp_log_files_"$(date +"%Y%m%d_%H%M")".tar.bz2"
    tar cjf $tar_filen_str "viirs_npp"
    cd - &> /dev/null
    
    echo "Email the file $tar_filen_str to Willem.Marais@ssec.wisc.edu. This compressed tar file contains the log files. The log files will be used to diagnose the error."
else
    echo 'VIIRS NPP test passed!'
fi
