#!/bin/bash

if [ -z "$MIPS_HOME" ]; then
    echo "(ERROR) The environment variable MIPS_HOME is not defined."
    exit 1
fi

if [ $# -ne 3 ]; then
    echo "(ERROR)"
    echo "    Usage: "$(basename $0)" <base scratch directory> <log directory> <file path to GMTCO>"
    exit 1
fi

base_scratch_dir=$1
log_dir=$2
gmtco_file_path_str=$3

FILEP_STR=$(readlink -f $0)
DATA_DIR_STR=$(dirname $FILEP_STR)"/viirs_suomi_npp"

# Load MIPS configuration
source $MIPS_HOME/scripts/environment/default/mips_viirs_env.bash

# Get the date and time information.
gmtco_file_str=$(basename $gmtco_file_path_str)
date_str=$(echo $gmtco_file_str | cut -d"_" -f 3)
time_start_str=$(echo $gmtco_file_str | cut -d"_" -f 4)
time_end_str=$(echo $gmtco_file_str | cut -d"_" -f 5)

date_time_str=$date_str"_"$time_start_str"_"$time_end_str

svi01_file_path_str=$(find $DATA_DIR_STR/ -name "SVI01_npp_"$date_time_str"_*.h5" | tail -n 1)
svi02_file_path_str=$(find $DATA_DIR_STR/ -name "SVI02_npp_"$date_time_str"_*.h5" | tail -n 1)
svm02_file_path_str=$(find $DATA_DIR_STR/ -name "SVM02_npp_"$date_time_str"_*.h5" | tail -n 1)
svm03_file_path_str=$(find $DATA_DIR_STR/ -name "SVM03_npp_"$date_time_str"_*.h5" | tail -n 1)
svm04_file_path_str=$(find $DATA_DIR_STR/ -name "SVM04_npp_"$date_time_str"_*.h5" | tail -n 1)
svm05_file_path_str=$(find $DATA_DIR_STR/ -name "SVM05_npp_"$date_time_str"_*.h5" | tail -n 1)
svm07_file_path_str=$(find $DATA_DIR_STR/ -name "SVM07_npp_"$date_time_str"_*.h5" | tail -n 1)
svm11_file_path_str=$(find $DATA_DIR_STR/ -name "SVM11_npp_"$date_time_str"_*.h5" | tail -n 1)

# Create a temporary scratch directory
scratch_dir_name_str="viirs_"$date_time_str"_scratch"
scratch_dir=$base_scratch_dir"/"$scratch_dir_name_str
mkdir -p $scratch_dir
# Go into the scratch directory
cd $scratch_dir

log_filep_str=$log_dir"/"$gmtco_file_str".log"

$MIPS_HOME/scripts/process_granule_tiles_viirs_wrap.bash \
    $svi01_file_path_str \
    $svi02_file_path_str \
    $svm02_file_path_str \
    $svm03_file_path_str \
    $svm04_file_path_str \
    $svm05_file_path_str \
    $svm07_file_path_str \
    $svm11_file_path_str \
    $gmtco_file_path_str &> $log_filep_str

grep "ERROR" $log_filep_str &> /dev/null
if [ $? -eq 0 ]; then 
    echo "(ERROR) Test failed on "$gmtco_file_str
    cd $base_scratch_dir
    tar cf $scratch_dir_name_str".tar" $scratch_dir_name_str
    
    exit 1
fi

# Go out the scratch directory
cd $base_scratch_dir
# Remove scratch directory
rm -r $scratch_dir
