#!/bin/bash

# Double check if the product environmental variables point to the actual data 
# directories, and not to a home or root directory. We don't want to accidently 
# delete non-product related files.
tmp_val=$(basename $MIPS_TILE_DIR)
if [ "$tmp_val" != "tiles" ]; then
    echo "(ERROR) The environmental variable MIPS_TILE_DIR does not point to a directory called 'tiles'"
    exit 1
fi

tmp_val=$(basename $MIPS_KML_DIR)
if [ "$tmp_val" != "kml" ]; then
    echo "(ERROR) The environmental variable MIPS_KML_DIR does not point to a directory called 'kml'"
    exit 1
fi

tmp_val=$(basename $MIPS_SUBSET_DIR)
if [ "$tmp_val" != "subsets" ]; then
    echo "(ERROR) The environmental variable MIPS_SUBSET_DIR does not point to a directory called 'subsets'"
    exit 1
fi

tmp_val=$(basename $MIPS_GRAN_IMG_DIR)
if [ "$tmp_val" != "granimg" ]; then
    echo "(ERROR) The environmental variable MIPS_GRAN_IMG_DIR does not point to a directory called 'granimg'"
    exit 1
fi

tmp_val=$(basename $MIPS_POLR_TILE_DIR)
if [ "$tmp_val" != "polartiles" ]; then
    echo "(ERROR) The environmental variable MIPS_POLR_TILE_DIR does not point to a directory called 'polartiles'"
    exit 1
fi

tmp_val=$(basename $MIPS_MOSAIC_DIR)
if [ "$tmp_val" != "mosaic" ]; then
    echo "(ERROR) The environmental variable MIPS_MOSAIC_DIR does not point to a directory called 'mosaic'"
    exit 1
fi

# =============================================================================
# Remove tile files
# =============================================================================
# Make a list of all the png image files in the tile directory
if [ -e $MIPS_TILE_DIR ]; then
    #tmp_file=$(mktemp)
    #find $MIPS_TILE_DIR -name "*.png" -type f -mmin +"$MIPS_LIFET_INTERM" -print > $tmp_file
    #
    # Go through every png tile file, and remove all revelant files
    #for file_name in $(cat $tmp_file); do
    #    file_dir=$(dirname $file_name)
    #    file_base=$(basename $file_name ".png")
    #
    #    rm $file_dir/$file_base.* &> /dev/null
    #done
    #
    #rm $tmp_file &> /dev/null
    
    find $MIPS_TILE_DIR -type f -mmin +"$MIPS_LIFET_INTERM" -exec rm {} \;
fi

# =============================================================================
# Remove polar tile files
# =============================================================================
# Make a list of all the png image files in the tile directory
if [ -e $MIPS_POLR_TILE_DIR ]; then
    #tmp_file=$(mktemp)
    #find $MIPS_POLR_TILE_DIR -name "*.png" -type f -mmin +"$MIPS_LIFET_INTERM" -print > $tmp_file
    #
    # Go through every png tile file, and remove all revelant files
    #for file_name in $(cat $tmp_file); do
    #    file_dir=$(dirname $file_name)
    #    file_base=$(basename $file_name ".png")
    #
    #    rm $file_dir/$file_base.* &> /dev/null
    #done
    #
    #rm $tmp_file &> /dev/null
    
    find $MIPS_POLR_TILE_DIR -type f -mmin +"$MIPS_LIFET_INTERM" -exec rm {} \;
fi

# =============================================================================
# Remove granule image files
# =============================================================================
if [ -e $MIPS_GRAN_IMG_DIR ]; then 
    find $MIPS_GRAN_IMG_DIR -type f -mmin +"$MIPS_LIFET_PRODUC" -exec /bin/rm {} \;
fi

# =============================================================================
# Remove KML directories
# =============================================================================
if [ -e $MIPS_KML_DIR ]; then
    if [ -e $MIPS_KML_DIR/intermediate ]; then
        find $MIPS_KML_DIR/intermediate -maxdepth 1 -type d -mmin +"$MIPS_LIFET_INTERM" -exec /bin/rm -r {} \;
    fi
    find $MIPS_KML_DIR -maxdepth 1 -type d -mmin +"$MIPS_LIFET_PRODUC" -exec /bin/rm -r {} \;
fi

# =============================================================================
# Remove subset files
# =============================================================================
if [ -e $MIPS_SUBSET_DIR ]; then
    find $MIPS_SUBSET_DIR -type f -mmin +"$MIPS_LIFET_PRODUC" -exec /bin/rm {} \;
fi

# =============================================================================
# Remove mosiac files
# =============================================================================
if [ -e $MIPS_MOSAIC_DIR ]; then
    find $MIPS_MOSAIC_DIR -type f -mmin +"$MIPS_LIFET_PRODUC" -exec /bin/rm {} \;
fi
