#!/bin/bash

if [ $# -ne 3 ]; then
    echo "(ERROR) Usage:"
    echo "    "$(basename $0)" <packages directory> <compile root directory> <MIPS binary directory>"
    
    exit 1
fi

pack_dir=$1
compile_dir=$2
mips_bin_dir=$3

# Check if the installation package exits
if [ ! -e $pack_dir ]; then
    echo "(ERROR) The compile install package directory does not exists."
    exit 1
fi

cd $pack_dir
if [ ! -e hdf5-1.6.10.tar.bz2 ] || [ ! -e hdf-4.2.5.tar.bz2 ] || [ ! -e szip-2.1.tar.gz ] || [ ! -e zlib-1.2.5.tar.bz2 ]; then
    echo "(ERROR) Not all the packages are present in the $pack_dir directory."
    exit 1
fi

if [ ! -e jpegsrc.v6b.tar.gz ] || [ ! -e h4h5tools-2.1.1.tar.gz ] || [ ! -e h4h5tools-2.1.1.patch.static ]; then
    echo "(ERROR) Not all the packages are present in the $pack_dir directory."
    exit 1
fi

if [ ! -e ms2gt0.22.tar.gz ] || [ ! -e ms2gt0.22.patch.static ]; then
    echo "(ERROR) Not all the packages are present in the $pack_dir directory."
    exit 1
fi

if [ ! -e proj-4.7.0.tar.gz ]; then
    echo "(ERROR) Not all the packages are present in the $pack_dir directory."
    exit 1
fi

if [ ! -e libgeotiff-1.3.0.tar.gz ] || [ ! -e libgeotiff-1.3.0.patch.static ] || [ ! -e tiff-3.9.4.tar.gz ]; then
    echo "(ERROR) Not all the packages are present in the $pack_dir directory."
    exit 1
fi

if [ ! -e modis_crefl_1.4.2a.tar.bz2 ] || [ ! -e libpng-1.5.4.tar.gz ] || [ ! -e bc-1.06.tar.gz ]; then
    echo "(ERROR) Not all the packages are present in the $pack_dir directory."
    exit 1
fi
cd -

# Make sure that previous temporary installation diretories are removed to prevent possible installation problems
rm -rf $compile_dir/h5h4tools $compile_dir/ms2gt-compile $compile_dir/proj4 \
    $compile_dir/geotiff $compile_dir/libtiff $compile_dir/modis_crefl

# Unpacking and compiling HDF libaries (version 4 and 5) and tools
# ================================================================
echo "========= HDF LIBARIES ========="
# B: Unpack HDFs
mkdir $compile_dir/h5h4tools
cd $compile_dir/h5h4tools
tar xjf $pack_dir/hdf5-1.6.10.tar.bz2
tar xjf $pack_dir/hdf-4.2.5.tar.bz2
tar xzf $pack_dir/szip-2.1.tar.gz
tar xjf $pack_dir/zlib-1.2.5.tar.bz2
tar xzf $pack_dir/jpegsrc.v6b.tar.gz
tar xzf $pack_dir/h4h5tools-2.1.1.tar.gz
# E: Unpack HDFs
# B: Copy patch
cp $pack_dir/h4h5tools-2.1.1.patch.static  $compile_dir/h5h4tools
# E: Copy patch
# B: Unpack zlib
mkdir $compile_dir/local-install
cd zlib-1.2.5
CFLAGS="-D_GNU_SOURCE" LDFLAGS="-L/lib -L/usr/lib" ./configure --prefix=$compile_dir/local-install
make -j3
make install
cd ..
# E: Unpack zlib
# B: Unpack szip
cd szip-2.1
./configure --prefix=$compile_dir/local-install
make -j3
make install
cd ..
# E: Unpack szip
# B: Unpack jpeg
mkdir -p $compile_dir/local-install/bin $compile_dir/local-install/man1
cd jpeg-6b
CFLAGS="-D_GNU_SOURCE -fPIC" ./configure --prefix=$compile_dir/local-install
make -j3
make install
make install-lib
cd ..
# E: Unpack jpeg
# B: Unpack hdf4
cd hdf-4.2.5
CFLAGS="-O0 -D_GNU_SOURCE" LDFLAGS="-L/lib -L/usr/lib -L$compile_dir/local-install/lib" CPPFLAGS="-I$compile_dir/local-install/include" ./configure --disable-fortran --with-szlib=no --prefix=$compile_dir/local-install
make -j3
make install
# Compile ncdump statically
cd mfhdf/ncdump
gcc -static  -o ncdump ncdump.o vardata.o dumplib.o $compile_dir/local-install/lib/libmfhdf.a $compile_dir/local-install/lib/libdf.a $compile_dir/local-install/lib/libjpeg.a $compile_dir/local-install/lib/libz.a
cp ncdump $compile_dir/local-install/bin/ncdump
cd ../../..
# E: Unpack hdf4
# B: Unpack hdf5
cd hdf5-1.6.10
CFLAGS="-O0 -D_GNU_SOURCE" LDFLAGS="-L/lib -L/usr/lib -L$compile_dir/local-install/lib" CPPFLAGS="-I$compile_dir/local-install/include" ./configure --disable-fortran --with-szlib --enable-static-exec --prefix=$compile_dir/local-install
make -j3
make install
cd ..
# E: Unpack hdf5
# B: Unpack h4h5tools
cd h4h5tools-2.1.1
patch -p1 -i ../h4h5tools-2.1.1.patch.static
LIBS="-ldf -lmfhdf -lz -ljpeg -lm" CFLAGS="-O0 -D_GNU_SOURCE" LDFLAGS="-L/lib -L/usr/lib -L$compile_dir/local-install/lib" CPPFLAGS="-I$compile_dir/local-install/include" ./configure  --enable-static-exec --prefix=$compile_dir/local-install
make -j3
make install
cd ..
# E: Unpack h4h5tools
# Unpacking and compiling ms2gt
# =============================
echo "========= MS2GT ========="
# B: Unpack ms2gt
mkdir $compile_dir/ms2gt-compile
cd $compile_dir/ms2gt-compile
tar xzf $pack_dir/ms2gt0.22.tar.gz
cp $pack_dir/ms2gt0.22.patch.static .
# E: Unpack ms2gt
# B: Patch,compile ms2gt
cd ms2gt0.22
patch -p1 -i ../ms2gt0.22.patch.static
cd src
make
cd ..
# E: Patch,compile ms2gt
# Unpack and install CREFL for MODIS
# ==================================
echo "========= MODIS CREFL ========="
# B: Unpack,compile MODIS CREFL
mkdir $compile_dir/modis_crefl
cd $compile_dir/modis_crefl
tar xjf $pack_dir/modis_crefl_1.4.2a.tar.bz2
cd modis_crefl_1.4.2a
LDFLAGS="-L/lib -L/usr/lib" CFLAGS="-D_GNU_SOURCE" HDFHOME=$compile_dir/local-install make
# E: Unpack,compile MODIS CREFL
# Unpack and install proj4
# ========================
echo "========= PROJ4 ========="
# B: Unpack proj4
mkdir $compile_dir/proj4
cd $compile_dir/proj4

tar xzf $pack_dir/proj-4.7.0.tar.gz
cd proj-4.7.0
# E: Unpack proj4
# B: Configure,compile proj4
CFLAGS="-D_GNU_SOURCE" LDFLAGS="-L/lib -L/usr/lib" ./configure --prefix=$compile_dir/local-install
make -j3
# E: Configure,compile proj4
# B: Manually compile proj4 bins
cd src
gcc -L/lib -L/usr/lib -static -o proj proj.o gen_cheb.o p_series.o .libs/libproj.a -lm /usr/lib/libpthread.a
strip proj
gcc -L/lib -L/usr/lib -static -o cs2cs cs2cs.o gen_cheb.o p_series.o .libs/libproj.a -lm /usr/lib/libpthread.a
strip cs2cs
cd ..
# E: Manually compile proj4 bins
# B: Install proj4
make install
# E: Install proj4
# Unpack and install geotiff 
# ==========================
echo "========= GEOTIFF ========="
# B: Unpack libtiff
mkdir $compile_dir/libtiff
cd $compile_dir/libtiff

tar xzf $pack_dir/tiff-3.9.4.tar.gz
cd tiff-3.9.4
# E: Unpack libtiff
# B: Configure,compile libtiff
CFLAGS="-D_GNU_SOURCE" LDFLAGS="-L/lib -L/usr/lib" ./configure --prefix=$compile_dir/local-install --enable-static
make -j3
make install
# E: Configure,compile libtiff
# B: Unpack geotiff
mkdir $compile_dir/libgeotiff
cd $compile_dir/libgeotiff

tar xzf $pack_dir/libgeotiff-1.3.0.tar.gz
cp $pack_dir/libgeotiff-1.3.0.patch.static .
cd libgeotiff-1.3.0
# E: Unpack geotiff
# B: Configure,compile geotiff
patch -p1 -i ../libgeotiff-1.3.0.patch.static
CFLAGS="-D_GNU_SOURCE" LDFLAGS="-L/lib -L/usr/lib -L$compile_dir/local-install/lib -L$compile_dir/local-install/lib" CPPFLAGS="-I$compile_dir/local-install/include -I$compile_dir/local-install/include" LIBS="-lpthread" ./configure --prefix=$compile_dir/local-install --enable-static 
make -j3
make install
# E: Configure,compile geotiff
echo "========= LIBPNG ========="
mkdir $compile_dir/libpng
cd $compile_dir/libpng

tar xzf $pack_dir/libpng-1.5.4.tar.gz
cd libpng-1.5.4
LDFLAGS="-L$compile_dir/local-install/lib" CPPFLAGS="-I$compile_dir/local-install/include" ./configure --prefix=$compile_dir/local-install
make -j3
make install

echo "========= BC ========="
mkdir $compile_dir/bc
cd $compile_dir/bc

tar xzf $pack_dir/bc-1.06.tar.gz
cd bc-1.06
CFLAGS="-static" ./configure --prefix=$compile_dir/local-install
make -j3
make install

# Copy installed binaries to MIPS bin directory
# =============================================
# B: Copy binaires to MIPS bin
cp $compile_dir/local-install/bin/h5dump $mips_bin_dir
cp $compile_dir/local-install/bin/h5toh4 $mips_bin_dir
cp $compile_dir/local-install/bin/ncdump $mips_bin_dir
cp $compile_dir/ms2gt-compile/ms2gt0.22/bin/fornav $mips_bin_dir
cp $compile_dir/ms2gt-compile/ms2gt0.22/bin/ll2cr $mips_bin_dir
cp $compile_dir/modis_crefl/modis_crefl_1.4.2a/tbase.hdf $mips_bin_dir
cp $compile_dir/modis_crefl/modis_crefl_1.4.2a/crefl.1.4.2 $mips_bin_dir
cp $compile_dir/local-install/bin/cs2cs $mips_bin_dir
cp $compile_dir/local-install/bin/geotifcp $mips_bin_dir
cp $compile_dir/local-install/bin/listgeo $mips_bin_dir
cp $compile_dir/local-install/bin/bc $mips_bin_dir
# E: Copy binaires to MIPS bin
