#!/bin/bash

if [ -z $MIPS_TILE_DIR ]; then
    echo "(ERROR) The environmental variable MIPS_TILE_DIR has not been defined."
    exit 1
fi

if [ $# -ne 3 ]; then
    echo "Usage: "
    echo "    "$(basename $0)" <tile directory> <band combination> <record file>"
    
    exit 1
fi

tile_dir=$1
band_comb_str=$2
record_file=$3

if [ ! -f $record_file ]; then
    # Make a list of the tile images
    tmp_event_file_lst=$(mktemp)
    tmp_uniq_event_file_lst=$(mktemp)
    tmp_filt_event_file_lst=$(mktemp)
    tmp_final_event_file_lst=$(mktemp)

    find $tile_dir -name tile*.*.*.$band_comb_str.*.png -type f -print > $tmp_event_file_lst
    for file_str in $(cat $tmp_event_file_lst); do
        bs_file_str=$(basename $file_str)
        part_str=$(echo $bs_file_str | cut -d"." -f 1-4)
        
        echo $part_str >> $tmp_uniq_event_file_lst
    done

    tmp_file_str="tmp_file_str.txt"
    sort $tmp_uniq_event_file_lst > $tmp_file_str
    uniq $tmp_file_str > $tmp_uniq_event_file_lst

    for uniq_file_str in $(cat $tmp_uniq_event_file_lst); do
        grep $uniq_file_str $tmp_event_file_lst > $tmp_filt_event_file_lst
        /bin/bash $MIPS_HOME/scripts/auxiliary/sort_comp_img_filelst.bash $tmp_filt_event_file_lst $tmp_final_event_file_lst 5
        
        file_str=$(tail -n 1 $tmp_final_event_file_lst)
        bs_file_str=$(basename $file_str)
        dirname_str=$(dirname $file_str)
        
        part_str=$(echo $bs_file_str | cut -d"." -f 1-5)
        bs_event_str="kml."$part_str".event"
        event_file_str=$dirname_str/$bs_event_str
        
        touch $event_file_str
        echo $event_file_str >> $record_file
    done

    rm -f $tmp_event_file_lst $tmp_uniq_event_file_lst $tmp_filt_event_file_lst $tmp_final_event_file_lst $tmp_file_str
else
    for file_str in $(cat $record_file); do
        touch $file_str
    done
fi

