#!/bin/bash

source $MIPS_HOME/scripts/mips_modis_env.bash
export MIPS_DEBUG='YES'
MIPS_AUX=$MIPS_HOME/scripts/auxiliary

if [ $# -ne 6 ]; then
    echo "(ERROR) Usage:"
    echo "    "$(basename $0)" <1000m L1B> <500m L1B> <250m L1B> <Geolocation L1B> <polar-north | polar-south | normal> <process dir>"
    
    exit 1
fi

file_1km=$1
file_hkm=$2
file_qkm=$3
file_geo=$4
proj_type=$5
process_dir=$6

mkdir -p $process_dir

bsn_file_1km=$(basename $file_1km)
satcode=$(echo $bsn_file_1km | cut -c1-3 | tr "[:upper:]" "[:lower:]")
if [ "$satcode" == "mod" ]; then
    satname="terra"
else
    satname="aqua"
fi
year_str=$(echo $bsn_file_1km | cut -d"." -f 2 | cut -c2-5)
julday_str=$(echo $bsn_file_1km | cut -d"." -f 2 | cut -c6-8)
# Convert julian day to normal day value
yeardate_str=$(date -d "$year_str-01-01 +$julday_str days -1 day" "+%Y%m%d")
time_str=$(echo $bsn_file_1km | cut -d"." -f 3)

new_h4_file_qkm=$satname".qkm."$yeardate_str"."$time_str".hdf"
new_h4_file_hkm=$satname".hkm."$yeardate_str"."$time_str".hdf"
new_h4_file_1km=$satname".1km."$yeardate_str"."$time_str".hdf"

# Duplicate the input L1B HDF5 files
cp $file_1km $process_dir/$new_h4_file_1km
cp $file_hkm $process_dir/$new_h4_file_hkm
cp $file_qkm $process_dir/$new_h4_file_qkm

cd $process_dir

ref_1km=$satname."1km".$yeardate_str.$time_str.crefl.hdf
ref_hkm=$satname."hkm".$yeardate_str.$time_str.crefl.hdf
ref_qkm=$satname."qkm".$yeardate_str.$time_str.crefl.hdf
echo "(CREFL)"
echo "    "/bin/bash $MIPS_AUX/process_granule_crefl.bash modis $new_h4_file_1km $new_h4_file_hkm $new_h4_file_qkm $ref_1km $ref_hkm $ref_qkm

/bin/bash $MIPS_AUX/process_granule_crefl.bash modis $new_h4_file_1km $new_h4_file_hkm $new_h4_file_qkm $ref_1km $ref_hkm $ref_qkm

# If an error occured, exit immediately.
if [ $? -ne 0 ]; then
    cd -
    exit 1
fi

# Clean the scratch directory incase there are previous data of a previous execution
rm -f *.{tif,png,txt,dat,pro,mpp,gpd} runidl tmp* template.* *.proj *.bin

out_png_img=$satname".qkm."$yeardate_str"."$time_str".png"
out_bin_zen=$satname".qkm."$yeardate_str"."$time_str".szen.bin"
echo "(Projecting)"
echo "    "/bin/bash $MIPS_AUX/run_reproject_ms2gt.bash $file_geo $ref_qkm $ref_hkm "$proj_type" $out_png_img $out_bin_zen

/bin/bash $MIPS_AUX/run_reproject_ms2gt.bash $file_geo $ref_qkm $ref_hkm "$proj_type" $out_png_img $out_bin_zen

cd -

