#!/bin/bash

source $MIPS_HOME/scripts/mips_viirs_env.bash
export MIPS_DEBUG='YES'
MIPS_AUX=$MIPS_HOME/scripts/auxiliary

echo $#

if [ $# -lt 5 ]; then
    echo "(ERROR) Usage:"
    echo "    "$(basename $0)" <polar-north | polar-south | normal> <band combination> <process dir> <GMTCO> <SVM/SVI files>"
    
    exit 1
fi

proj_type=$1
band_comb_str=$2
process_dir=$3
gmtco_file=$4
shift 4
svm_svi_lst=$*

#svm02_file=$1
#svm03_file=$2
#svm04_file=$3
#svm05_file=$4
#svm07_file=$5
#svi01_file=$6
#svi02_file=$7
#gmtco_file=$8
#proj_type=$9
#shift 2
#band_comb_str=$8
#process_dir=$9
#svm_svi_lst=$svm02_file" "$svm03_file" "$svm04_file" "$svm05_file" "$svm07_file" "$svi01_file" "$svi02_file

export MIPS_DEFAULT_BANDCOMB=$band_comb_str

mkdir -p $process_dir

bsn_file_gmtco=$(basename $gmtco_file)
satname=$(echo $bsn_file_gmtco | cut -d"_" -f 2 | tr "[:upper:]" "[:lower:]")

yeardate_str=$(echo $bsn_file_gmtco | cut -d"_" -f 3 | cut -c2-)
time_str=$(echo $bsn_file_gmtco | cut -d"_" -f 4 | cut -c2-5)

cd $process_dir

# Clean the scratch directory incase there are previous data of a previous execution
rm -f *.{tif,png,txt,dat,pro,mpp,gpd} runidl tmp* template.* *.proj *.bin

/bin/bash $MIPS_AUX/hdf5_viirs_geodata_to_bin.bash $gmtco_file "lat_km" "lon_km" "sensorzenithkm"
lat_km_bin_file=$(ls "lat_km"*".dat")
if [ ! -e $lat_km_file_bin ]; then
    echo "(ERROR)[Exx] The latitude binary file of the geolocation file "$(basename $gmtco_file)" does not exist."
    exit 1
fi

lon_km_bin_file=$(ls "lon_km"*".dat")
if [ ! -e $lon_km_file_bin ]; then
    echo "(ERROR)[Exx] The longitude binary file of the geolocation file "$(basename $gmtco_file)" does not exist."
    exit 1
fi

senz_bin_file=$(ls "sensorzenithkm"*".dat")
if [ ! -e $lon_km_file_bin ]; then
    echo "(ERROR)[Exx] The sensor zenith angle binary file of the geolocation file "$(basename $gmtco_file)" does not exist."
    exit 1
fi

ref_lres=$satname."lres".$yeardate_str.$time_str.crefl.hdf
ref_hres=$satname."hres".$yeardate_str.$time_str.crefl.hdf
echo "(CREFL)"
echo "    "/bin/bash $MIPS_AUX/process_granule_crefl.bash viirs $gmtco_file $svm_svi_lst $ref_lres $ref_hres

/bin/bash $MIPS_AUX/process_granule_crefl.bash viirs $gmtco_file $svm_svi_lst $ref_lres $ref_hres

# If an error occured, exit immediately.
if [ $? -ne 0 ]; then
    cd -
    exit 1
fi

out_png_img=$satname".hres"$yeardate_str"."$time_str"."$band_comb_str".png"
out_bin_zen=$satname".hres"$yeardate_str"."$time_str".szen.bin"
echo "(Projecting)"
echo "    "/bin/bash $MIPS_AUX/run_reproject_ms2gt.bash $lat_km_bin_file $lon_km_bin_file $senz_bin_file $ref_hres $ref_lres $proj_type $out_png_img $out_bin_zen

/bin/bash $MIPS_AUX/run_reproject_ms2gt.bash $lat_km_bin_file $lon_km_bin_file $senz_bin_file $ref_hres $ref_lres $proj_type $out_png_img $out_bin_zen

cd -

