#!/bin/bash

# Purpose: Execute a test case. Based on the given directory name, 
#     determine which test case script must be executed.
#     The test case directory naming convention is:
#     mips-x.x_<FY3A,FY3B,TERRA,AQUA>_<polar,nonpolar>_test_data

if [ -z $MIPS_HOME ]; then
    echo "(ERROR) Environmental variable MIPS_HOME is not defined"
    exit 1
fi

if [ $# -ne 2 ]; then
    echo "Usage: "
    echo "    "$(basename $0)" <:kml:subsets:polarmosiac:globalmosaic:none:> <test case directory path>"
    
    exit 1
fi

process_flags=$1
test_case_dir=$2
test_case_bsname=$(basename $test_case_dir)

sat_name=$(echo $test_case_bsname | cut -d"_" -f 2)
case $sat_name in 
    "TERRA" | "AQUA" )
        $MIPS_HOME/scripts/utilities/execute_test_case_modis.bash $test_case_dir $process_flags
    ;;
    
    "NPP" )
        $MIPS_HOME/scripts/utilities/execute_test_case_viirs.bash $test_case_dir $process_flags
    ;;

    * )
        echo "(ERROR) Unknown test case directory:"
        echo "    sat_name: "$sat_name
        echo "    test_case_bsname: "$test_case_bsname
        
        exit 1
    ;;
esac

