#!/bin/bash

# WARNING: Only used with MODIS data

if [ -z $MIPS_HOME ]; then
    echo "(ERROR) Environmental variable MIPS_HOME is not defined"
    exit 1
fi

if [ -z $MIPS_MODIS_TEST_DIR ]; then
    echo "(ERROR) Environmental variable MIPS_MODIS_TEST_DIR is not defined"
    exit 1
fi

if [ $# -ne 3 ]; then
    echo "Usage:"
    echo "    "$(basename $0)" <data file returned by script 'make_l1b_region_lst.bash'> <MIPS_PROC_STEPS> <Nr CPUs>"
    echo "For example:"
    echo "    "$(basename $0)" l1b_data_list.txt :crefl:gran_img:metadata:polarmetadata:tiles_img:polartiles_img:comps_img: 1"
    
    exit 1
fi

data_fil_lst=$1
set_mips_proc_steps=$2
nr_cpus=$3

source $MIPS_HOME/scripts/mips_modis_env.bash
MIPS_UTIL_DIR=$MIPS_HOME/scripts/utilities

export MIPS_GRAN_IMG_DIR=$MIPS_MODIS_TEST_DIR/granimg
export MIPS_TILE_DIR=$MIPS_MODIS_TEST_DIR/tiles
export MIPS_POLR_TILE_DIR=$MIPS_MODIS_TEST_DIR/polartiles
export MIPS_SUBSET_DIR=$MIPS_MODIS_TEST_DIR/subsets
export MIPS_MOSAIC_DIR=$MIPS_MODIS_TEST_DIR/mosaic
export MIPS_KML_DIR=$MIPS_MODIS_TEST_DIR/kml
export MIPS_TEST_LOG_DIR=$MIPS_MODIS_TEST_DIR/log
export MIPS_TEST_SCRATCH_DIR=$MIPS_MODIS_TEST_DIR/scratch

export MIPS_DEBUG="YES"

mkdir -p $MIPS_GRAN_IMG_DIR $MIPS_TILE_DIR $MIPS_POLR_TILE_DIR
mkdir -p $MIPS_SUBSET_DIR $MIPS_KML_DIR $MIPS_TEST_LOG_DIR
mkdir -p $MIPS_TEST_SCRATCH_DIR $MIPS_MOSAIC_DIR

export MIPS_PROC_STEPS="$set_mips_proc_steps"

for file_str in $(cat $data_fil_lst); do
    file_str=$(echo $file_str | cut -d":" -f 1)
    dir_name=$(dirname $file_str)
    base_dir=$(dirname $dir_name)
    file_name=$(basename $file_str)
    sat_code_str=$(echo $file_name | cut -c1-3)

    file_part=$(echo $file_name | cut -d"." -f 2-)

    mod02_1km=$file_str
    mod03_fil=$base_dir/$sat_code_str"03"/"$sat_code_str"03.$file_part
    mod02_hkm=$base_dir/$sat_code_str"02HKM"/$sat_code_str"02HKM".$file_part
    mod02_qkm=$base_dir/$sat_code_str"02QKM"/$sat_code_str"02QKM".$file_part
    
    mkdir -p $MIPS_TEST_SCRATCH_DIR/$file_name
cat > $MIPS_TEST_SCRATCH_DIR/$file_name/task.bash << EOF
cd $MIPS_TEST_SCRATCH_DIR/$file_name
$MIPS_UTIL_DIR/task_modis_tile.bash $mod03_fil $mod02_1km $mod02_hkm $mod02_qkm &> $MIPS_TEST_LOG_DIR/$file_name.log
exit_status=\$?
cd -
if [ \$exit_status -eq 0 ]; then
    rm -r $MIPS_TEST_SCRATCH_DIR/$file_name
fi
EOF

done

# If Sun Grid Engine - or a variant of it - is not available, use xargs
if [ -z $SGE_ROOT ]; then
    find $MIPS_TEST_SCRATCH_DIR -name task.bash -type f -print | xargs -P $nr_cpus -n 1 /bin/bash
else 
    for file_name_str in $(ls $MIPS_TEST_SCRATCH_DIR); do
        echo "/bin/bash $MIPS_TEST_SCRATCH_DIR/$file_name_str/task.bash" | qsub -q modis.q -V -N $(basename $file_name_str) -o $MIPS_TEST_LOG_DIR/sge.std.log -e $MIPS_TEST_LOG_DIR/sge.err.log
    done
fi
