#!/bin/bash

# WARNING: Only used with MODIS data

if [ -z $MIPS_HOME ]; then
    echo "(ERROR) Environmental variable MIPS_HOME is not defined"
    exit 1
fi

if [ -z $MIPS_VIIRS_TEST_DIR ]; then
    echo "(ERROR) Environmental variable MIPS_VIIRS_TEST_DIR is not defined"
    exit 1
fi

if [ $# -ne 3 ]; then
    echo "Usage:"
    echo "    "$(basename $0)" <data file returned by script 'make_l1b_region_lst.bash'> <MIPS_PROC_STEPS> <Nr CPUs>"
    echo "For example:"
    echo "    "$(basename $0)" l1b_data_list.txt :crefl:gran_img:metadata:polarmetadata:tiles_img:polartiles_img:comps_img: 1"
    
    exit 1
fi

data_fil_lst=$1
set_mips_proc_steps=$2
nr_cpus=$3

source $MIPS_HOME/scripts/mips_viirs_env.bash
MIPS_UTIL_DIR=$MIPS_HOME/scripts/utilities

export MIPS_GRAN_IMG_DIR=$MIPS_VIIRS_TEST_DIR/granimg
export MIPS_TILE_DIR=$MIPS_VIIRS_TEST_DIR/tiles
export MIPS_POLR_TILE_DIR=$MIPS_VIIRS_TEST_DIR/polartiles
export MIPS_SUBSET_DIR=$MIPS_VIIRS_TEST_DIR/subsets
export MIPS_MOSAIC_DIR=$MIPS_VIIRS_TEST_DIR/mosaic
export MIPS_KML_DIR=$MIPS_VIIRS_TEST_DIR/kml
export MIPS_TEST_LOG_DIR=$MIPS_VIIRS_TEST_DIR/log
export MIPS_TEST_SCRATCH_DIR=$MIPS_VIIRS_TEST_DIR/scratch

export MIPS_DEBUG="YES"

mkdir -p $MIPS_GRAN_IMG_DIR $MIPS_TILE_DIR $MIPS_POLR_TILE_DIR
mkdir -p $MIPS_SUBSET_DIR $MIPS_KML_DIR $MIPS_TEST_LOG_DIR
mkdir -p $MIPS_TEST_SCRATCH_DIR $MIPS_MOSAIC_DIR

export MIPS_PROC_STEPS="$set_mips_proc_steps"

for file_str in $(cat $data_fil_lst); do
    file_str=$(echo $file_str | cut -d":" -f 1)
    dir_name=$(dirname $file_str)
    base_dir=$(dirname $dir_name)
    file_name=$(basename $file_str)
	
	file_part=$(echo $file_name | cut -d"_" -f2-4)
	
	gmtco_file=$(ls $base_dir/"GMTCO"/"GMTCO_"$file_part*".h5")
	svi01_file=$(ls $base_dir/"SVI01"/"SVI01_"$file_part*".h5")
	svi02_file=$(ls $base_dir/"SVI02"/"SVI02_"$file_part*".h5")
	svm02_file=$(ls $base_dir/"SVM02"/"SVM02_"$file_part*".h5")
	svm03_file=$(ls $base_dir/"SVM03"/"SVM03_"$file_part*".h5")
	svm04_file=$(ls $base_dir/"SVM04"/"SVM04_"$file_part*".h5")
	svm05_file=$(ls $base_dir/"SVM05"/"SVM05_"$file_part*".h5")
	svm07_file=$(ls $base_dir/"SVM07"/"SVM07_"$file_part*".h5")
    
    mkdir -p $MIPS_TEST_SCRATCH_DIR/$file_name
cat > $MIPS_TEST_SCRATCH_DIR/$file_name/task.bash << EOF
cd $MIPS_TEST_SCRATCH_DIR/$file_name
$MIPS_UTIL_DIR/task_viirs_tile.bash $svi01_file $svi02_file $svm02_file $svm03_file $svm04_file $svm05_file $svm07_file $gmtco_file &> $MIPS_TEST_LOG_DIR/$file_name.log
exit_status=\$?
cd -
if [ \$exit_status -eq 0 ]; then
    rm -r $MIPS_TEST_SCRATCH_DIR/$file_name
fi
EOF

done

find $MIPS_TEST_SCRATCH_DIR -name task.bash -type f -print | xargs -P $nr_cpus -n 1 /bin/bash

# # If Sun Grid Engine - or a variant of it - is not available, use xargs
# if [ -z $SGE_ROOT ]; then
#     find $MIPS_TEST_SCRATCH_DIR -name task.bash -type f -print | xargs -P $nr_cpus -n 1 /bin/bash
# else 
#     for file_name_str in $(ls $MIPS_TEST_SCRATCH_DIR); do
#         echo "/bin/bash $MIPS_TEST_SCRATCH_DIR/$file_name_str/task.bash" | qsub -q modis.q -V -N $(basename $file_name_str) -o $MIPS_TEST_LOG_DIR/sge.std.log -e $MIPS_TEST_LOG_DIR/sge.err.log
#     done
# fi
