#!/bin/bash

# WARNING: Only used with MODIS data

if [ -z $MIPS_HOME ]; then
    echo "(ERROR) Environmental variable MIPS_HOME is not defined"
    exit 1
fi

if [ -z $MIPS_MODIS_TEST_DIR ]; then
    echo "(ERROR) Environmental variable MIPS_MODIS_TEST_DIR is not defined"
    exit 1
fi

if [ $# -ne 1 ]; then
    echo "Usage:"
    echo "    "$(basename $0)"  <log file path (log prefix str)>"
    
    exit 1
fi

prefix_log_file_path=$1

source $MIPS_HOME/scripts/mips_modis_env.bash
MIPS_UTIL_DIR=$MIPS_HOME/scripts/utilities

export MIPS_GRAN_IMG_DIR=$MIPS_MODIS_TEST_DIR/granimg
export MIPS_TILE_DIR=$MIPS_MODIS_TEST_DIR/tiles
export MIPS_POLR_TILE_DIR=$MIPS_MODIS_TEST_DIR/polartiles
export MIPS_SUBSET_DIR=$MIPS_MODIS_TEST_DIR/subsets
export MIPS_MOSAIC_DIR=$MIPS_MODIS_TEST_DIR/mosaic
export MIPS_KML_DIR=$MIPS_MODIS_TEST_DIR/kml
export MIPS_TEST_LOG_DIR=$MIPS_MODIS_TEST_DIR/log
export MIPS_TEST_SCRATCH_DIR=$MIPS_MODIS_TEST_DIR/scratch

export MIPS_DEBUG="YES"

log_file_path=$prefix_log_file_path".log"
kml_log_file_path=$prefix_log_file_path".kml.log"
polar_mosiac_log_file_path=$prefix_log_file_path".polar-mosiac.log"
global_mosiac_log_file_path=$prefix_log_file_path".global-mosiac.log"
subset_log_file_path=$prefix_log_file_path".subset.log"

echo "==================== INFO ====================" &>> $log_file_path
printenv                                              &>> $log_file_path
echo "==================== INFO ====================" &>> $log_file_path

echo "(Process KML)" &>> $log_file_path
$MIPS_HOME/scripts/process_kml.bash &> $kml_log_file_path

echo "(Process Subsets)" &>> $log_file_path
$MIPS_HOME/scripts/process_subsets.bash &> $subset_log_file_path

echo "(Process Polar Mosaic)" &>> $log_file_path
$MIPS_HOME/scripts/process_polar_mosaic.bash &> $polar_mosiac_log_file_path

echo "(Process Global Mosaic)" &>> $log_file_path
$MIPS_HOME/scripts/process_global_mosaic.bash &> $global_mosiac_log_file_path

